@@ -2,7 +2,8 @@
 ### Fit a Rasch model with a mixture of Polya Tree prior
 ### for the random effect distribution
 ###
-### Copyright: Alejandro Jara, 2006-2007-2008
+### Copyright: Alejandro Jara, 2006-2009.
+###
 ### Last modification: 30-09-2006.
 ###
 ### This program is free software; you can redistribute it and/or modify
@@ -22,16 +23,17 @@
 ### The author's contact information:
 ###
 ###      Alejandro Jara
-###      Biostatistical Centre
-###      Katholieke Universiteit Leuven
-###      U.Z. Sint-Rafal
-###      Kapucijnenvoer 35
-###      B-3000 Leuven
-###      Voice: +32 (0)16 336892  URL  : http://student.kuleuven.be/~s0166452/
-###      Fax  : +32 (0)16 337015  Email: Alejandro.JaraVallejos@med.kuleuven.be
+###      Department of Statistics
+###      Facultad de Ciencias Fsicas y Matemticas
+###      Universidad de Concepcin
+###      Avenida Esteban Iturra S/N
+###      Barrio Universitario
+###      Concepcin
+###      Chile
+###      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+###      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 ###
 
-
 FPTrasch<-function(y,prior,mcmc,state,status,grid=seq(-10,10,length=1000),delete=FALSE,data=sys.frame(sys.parent()))
 UseMethod("FPTrasch")
 
@@ -451,7 +453,6 @@ function(y,
   	 	m          =as.double(m),
   	 	prec       =as.double(prec),
   	 	s          =as.double(s),
- 		sb         =as.double(sb),
   	 	tau1       =as.double(tau1),
   	 	tau2       =as.double(tau2),
  		mcmc       =as.integer(mcmcvec),
