@@ -38,8 +38,7 @@ UseMethod("PTrandom")
 function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
 {
    comput<-0 
-
-   if(is(object, "PTlmm") || is(object, "PTglmm") || is(object, "PTolmm"))
+   if(is(object, "PTlmm"))
    {
       comput<-1
       random<-matrix(0,nrow=object$nsubject,ncol=object$nrandom)
@@ -150,64 +149,228 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
       }
    }
 
-   if(is(object, "PTmeta"))
+   if(is(object, "PTglmm"))
    {
-       comput<-1
-       if (centered) 
-       { 
-	   stop("This option is not implemented for PTmeta.\n")
-       }
-
-       randommat<-matrix(object$save.state$randsave,
-                  nrow=object$mcmc$nsave,ncol=object$nrec+1)
+      comput<-1   
+      random<-matrix(0,nrow=object$nsubject,ncol=object$nrandom)
+      predp<-rep(0,object$nrandom)
+      predsd<-rep(0,object$nrandom)
+      predse<-rep(0,object$nrandom)
+      predl<-rep(0,object$nrandom)
+      predu<-rep(0,object$nrandom)
+      predm<-rep(0,object$nrandom)
       
-       dimnames(randommat)<-dimnames(object$save.state$randsave)
+      randommat<-matrix(object$save.state$randsave,
+                 nrow=object$mcmc$nsave,ncol=object$nrandom*(object$nsubject+1))
+      
+      dimnames(randommat)<-dimnames(object$save.state$randsave)
+      
+      thetamat<-matrix(object$save.state$thetasave,nrow=object$mcmc$nsave, 
+                       ncol=object$dimen)
+      
+      counter<-0
+      for(i in 1:object$nsubject){
+          for(j in 1:object$nrandom){
+              counter<-counter+1
+              if(centered)
+              {
+                   random[i,j]<-mean(object$save.state$randsave[,counter]-
+                                     object$save.state$thetasave[,j])
+              }
+              else
+              {
+                   random[i,j]<-mean(object$save.state$randsave[,counter])              
+              }
+          }
+      }
+      
+      type<-1
+      dimnames(random)<-list(object$namesre1,object$namesre2)
+      z<-list(randomm=random,randommat=randommat,thetamat=thetamat,centered=centered,
+              predictive=predictive,nsubject=object$nsubject,nrandom=object$nrandom,
+              modelname=object$modelname,call=object$call,type=type,nsave=object$mcmc$nsave)
+      
+      if(predictive==TRUE)
+      {
+      	 for(i in 1:object$nrandom)
+      	 { 		
+      	     counter<-counter+1	
+      	     if(centered)
+      	     {
+                predp[i]<-mean(object$save.state$randsave[,counter]-
+                                object$save.state$thetasave[,i])      	     	
+
+                predm[i]<-median(object$save.state$randsave[,counter]-
+                                object$save.state$thetasave[,i])      	     	
+
+                predsd[i]<-sqrt(var(object$save.state$randsave[,counter]-
+                                object$save.state$thetasave[,i]))      	     	
+
+                vec<-object$save.state$randsave[,counter]-object$save.state$thetasave[,i]
+                
+                n<-length(vec)
+                
+                alpha<-0.05
+                
+                alow<-rep(0,2)
+                
+                aupp<-rep(0,2)
+                
        
-       random<-apply(object$save.state$randsave,2,mean)
-       random<-random[-(object$nrec+1)]
+                a<-.Fortran("hpd",n=as.integer(n),alpha=as.double(alpha),x=as.double(vec),
+                            alow=as.double(alow),aupp=as.double(aupp),PACKAGE="DPpackage")
+                predl[i]<-a$alow[1]            
+                predu[i]<-a$aupp[1]
+                
+                predse[i]<-predsd[i]/sqrt(n)
+      	     }
+      	     else
+      	     {
+                predp[i]<-mean(object$save.state$randsave[,counter])      	     	
+
+                predm[i]<-median(object$save.state$randsave[,counter])      	     	
+
+                predsd[i]<-sqrt(var(object$save.state$randsave[,counter]))      	     	
+
+                vec<-object$save.state$randsave[,counter]
+                
+                n<-length(vec)
+                
+                alpha<-0.05
+                
+                alow<-rep(0,2)
+                
+                aupp<-rep(0,2)
+                
        
-       random<-as.matrix(random,ncol=1)
-       colnames(random)<-names(object$coefficients)[1]
-
-       type<-2      
-       z<-list(randomm=random,modelname=object$modelname,call=object$call,predictive=predictive,
-               nsubject=object$nrec,nrandom=1,centered=FALSE,randommat=randommat,
-               type=type,nsave=object$mcmc$nsave)
-
-       if(predictive==TRUE)
-       {
-          predp<-mean(object$save.state$randsave[,object$nrec+1])      	     	
-
-          predm<-median(object$save.state$randsave[,object$nrec+1])      	     	
-
-          predsd<-sqrt(var(object$save.state$randsave[,object$nrec+1]))      	     	
-
-          vec<-object$save.state$randsave[,object$nrec+1]
-          
-          n<-length(vec)
-          
-          alpha<-0.05
-          
-          alow<-rep(0,2)
-          
-          aupp<-rep(0,2)
-          
-       
-          a<-.Fortran("hpd",n=as.integer(n),alpha=as.double(alpha),x=as.double(vec),
-                      alow=as.double(alow),aupp=as.double(aupp),PACKAGE="DPpackage")
-          predl<-a$alow[1]            
-          predu<-a$aupp[1]
-          
-          predse<-predsd/sqrt(n)
-     	 
-      	  predtable <- cbind(predp, predm, predsd, predse , predl , predu)
-          dimnames(predtable) <- list("theta", c("Mean", "Median", "Std. Dev.", "Naive Std.Error",
+                a<-.Fortran("hpd",n=as.integer(n),alpha=as.double(alpha),x=as.double(vec),
+                            alow=as.double(alow),aupp=as.double(aupp),PACKAGE="DPpackage")
+                predl[i]<-a$alow[1]            
+                predu[i]<-a$aupp[1]
+                
+                predse[i]<-predsd[i]/sqrt(n)
+      	     }
+      	 }
+      	 
+      	 predtable <- cbind(predp, predm, predsd, predse , predl , predu)
+         dimnames(predtable) <- list(object$namesre2, c("Mean", "Median", "Std. Dev.", "Naive Std.Error",
                 "95%HPD-Low","95%HPD-Upp"))
       	 
-      	  z$prediction<-predtable
-       }
+      	 z$prediction<-predtable
+      }
    }
 
+   if(is(object, "PTolmm"))
+   {
+      comput<-1   
+      random<-matrix(0,nrow=object$nsubject,ncol=object$nrandom)
+      predp<-rep(0,object$nrandom)
+      predsd<-rep(0,object$nrandom)
+      predse<-rep(0,object$nrandom)
+      predl<-rep(0,object$nrandom)
+      predu<-rep(0,object$nrandom)
+      predm<-rep(0,object$nrandom)
+      
+      randommat<-matrix(object$save.state$randsave,
+                 nrow=object$mcmc$nsave,ncol=object$nrandom*(object$nsubject+1))
+      
+      dimnames(randommat)<-dimnames(object$save.state$randsave)
+      
+      thetamat<-matrix(object$save.state$thetasave,nrow=object$mcmc$nsave, 
+                       ncol=object$dimen)
+      
+      counter<-0
+      for(i in 1:object$nsubject){
+          for(j in 1:object$nrandom){
+              counter<-counter+1
+              if(centered)
+              {
+                   random[i,j]<-mean(object$save.state$randsave[,counter]-
+                                     object$save.state$thetasave[,j])
+              }
+              else
+              {
+                   random[i,j]<-mean(object$save.state$randsave[,counter])              
+              }
+          }
+      }
+
+      type<-1      
+      dimnames(random)<-list(object$namesre1,object$namesre2)
+      z<-list(randomm=random,randommat=randommat,thetamat=thetamat,centered=centered,
+              predictive=predictive,nsubject=object$nsubject,nrandom=object$nrandom,
+              modelname=object$modelname,call=object$call,type=type,nsave=object$mcmc$nsave)
+      
+      if(predictive==TRUE)
+      {
+      	 for(i in 1:object$nrandom)
+      	 { 		
+      	     counter<-counter+1	
+      	     if(centered)
+      	     {
+                predp[i]<-mean(object$save.state$randsave[,counter]-
+                                object$save.state$thetasave[,i])      	     	
+
+                predm[i]<-median(object$save.state$randsave[,counter]-
+                                object$save.state$thetasave[,i])      	     	
+
+                predsd[i]<-sqrt(var(object$save.state$randsave[,counter]-
+                                object$save.state$thetasave[,i]))      	     	
+
+                vec<-object$save.state$randsave[,counter]-object$save.state$thetasave[,i]
+                
+                n<-length(vec)
+                
+                alpha<-0.05
+                
+                alow<-rep(0,2)
+                
+                aupp<-rep(0,2)
+                
+       
+                a<-.Fortran("hpd",n=as.integer(n),alpha=as.double(alpha),x=as.double(vec),
+                            alow=as.double(alow),aupp=as.double(aupp),PACKAGE="DPpackage")
+                predl[i]<-a$alow[1]            
+                predu[i]<-a$aupp[1]
+                
+                predse[i]<-predsd[i]/sqrt(n)
+      	     }
+      	     else
+      	     {
+                predp[i]<-mean(object$save.state$randsave[,counter])      	     	
+
+                predm[i]<-median(object$save.state$randsave[,counter])      	     	
+
+                predsd[i]<-sqrt(var(object$save.state$randsave[,counter]))      	     	
+
+                vec<-object$save.state$randsave[,counter]
+                
+                n<-length(vec)
+                
+                alpha<-0.05
+                
+                alow<-rep(0,2)
+                
+                aupp<-rep(0,2)
+                
+       
+                a<-.Fortran("hpd",n=as.integer(n),alpha=as.double(alpha),x=as.double(vec),
+                            alow=as.double(alow),aupp=as.double(aupp),PACKAGE="DPpackage")
+                predl[i]<-a$alow[1]            
+                predu[i]<-a$aupp[1]
+                
+                predse[i]<-predsd[i]/sqrt(n)
+      	     }
+      	 }
+      	 
+      	 predtable <- cbind(predp, predm, predsd, predse , predl , predu)
+         dimnames(predtable) <- list(object$namesre2, c("Mean", "Median", "Std. Dev.", "Naive Std.Error",
+                "95%HPD-Low","95%HPD-Upp"))
+      	 
+      	 z$prediction<-predtable
+      }
+   }
+   
 
    if(comput==1 && predictive==TRUE)
    {
@@ -220,14 +383,11 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
          m<-object$m
          nsubject<-object$nsubject 
          nfixed<-object$nfixed
-         typep<-object$typep
 
          dimen1<-object$nrandom+object$nfixed
          dimen2<-0
          if(is(object, "PTlmm"))dimen2<-1
          if(is(object, "PTglmm"))dimen2<-object$dispp
-         if(is(object, "PTmeta"))dimen2<-0
-         
          total<-dimen1+dimen2
          dimen3<-object$nrandom
          mumat<-object$save.state$thetasave[,(total+1):(total+dimen3)]
@@ -235,6 +395,10 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
          dimen4<-object$nrandom*(object$nrandom+1)/2
          sigmamat<-object$save.state$thetasave[,(total+1):(total+dimen4)]             
          cparvec<-object$save.state$thetasave[,(total+dimen4+1)]
+         total<-total+dimen4+1
+         dimen5<-object$nrandom*object$nrandom
+         typepmat<-object$save.state$thetasave[,(total+1):(total+dimen5)]
+
          nsave<-length(cparvec)
          randsave<-object$save.state$randsave
 
@@ -254,7 +418,8 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
          workmhr<-rep(0,q*(q+1)/2) 
          workmr<-matrix(0,nrow=q,ncol=q) 
          workmr1<-matrix(0,nrow=q,ncol=q) 
-         workmr2<-matrix(0,nrow=q,ncol=q) 
+         workmr2<-matrix(0,nrow=q,ncol=q)
+         ortho<-matrix(0,nrow=q,ncol=q)  
          workvr<-rep(0,q)
          workvr1<-rep(0,q)
 
@@ -279,6 +444,7 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
    	       grid<-seq(gridl[1],gridl[2],length=ngrid)  
    	    }
 
+            typep <- 1
             foo <- .Fortran("predictiveptu",
              	m          =as.integer(m),
    		nsubject   =as.integer(nsubject),
@@ -348,7 +514,8 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
 
             fs<-matrix(0,nrow=ngrid1,ncol=ngrid2)
 
-            foo <- .Fortran("predictiveptb",
+
+            foo <- .Fortran("predictiveptb2",
              	m          =as.integer(m),
    		nsubject   =as.integer(nsubject),
    		q          =as.integer(q),
@@ -357,7 +524,7 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
   		mumat      =as.double(mumat),
   		sigmamat   =as.double(sigmamat),
   		cparvec    =as.double(cparvec),
-  		typep      =as.integer(typep),
+  		typepmat   =as.double(typepmat),
   		ngrid1     =as.integer(ngrid1),
   		ngrid2     =as.integer(ngrid2),
   		grid1      =as.double(grid1),
@@ -377,11 +544,8 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
  	        theta      =as.double(theta),
  	        thetaz     =as.double(thetaz),
          	workmr     =as.double(workmr),
-         	workmr1    =as.double(workmr1),
-    		workmr2    =as.double(workmr2),
+         	ortho      =as.double(ortho),
  	        workmhr    =as.double(workmhr),
-     		workvr     =as.double(workvr),
-     		workvr1     =as.double(workvr1),
      		fixed      =as.integer(frstlprob),     		
 	        PACKAGE    ="DPpackage")
 
@@ -414,7 +578,7 @@ function(object,centered=FALSE,predictive=FALSE,ngrid=1000,gridl=NULL)
 
 "print.PTrandom"<-function (x, digits = max(3, getOption("digits") - 3), ...) 
 {
-    cat("\n","Random effect information for the PT object:","\n\nCall:\n",sep = "")
+    cat("\n","Random effect information for the DP object:","\n\nCall:\n",sep = "")
     print(x$call)
     cat("\n")
 
