@@ -1,16 +1,16 @@
 c=======================================================================                      
       subroutine dpmglmmgam(
-     &                  maxni,nrec,nsubject,nfixed,p,q,subject,datastr, #8
-     &                  y,x,z,roffset,                                  #4
-     &                  a0b0,prec,sb,nu,tinv1,smu,psiinv,tinv2,tau,     #9
-     &                  mcmc,nsave,                                     #2  
-     &                  ncluster,ss,alpha,beta,b,betar,mu,              #7
-     &                  sigma,sigmainv,mub,sigmab,sigmabinv,v,mc,       #7
-     &                  acrate,cpo,randsave,thetasave,musave,clustsave, #6
-     &                  iflagp,betac,workmhp,workvp,xtx,xty,            #6
-     &                  iflagr,theta,thetac,workmhr,workmhr2,workmr,    #6
-     &                  workvr,ztz,zty,cstrt,ccluster,prob,quadf,       #7
-     &                  seed,betasave,bsave)                            #3 
+     &                  maxni,nrec,nsubject,nfixed,p,q,subject,datastr, 
+     &                  y,x,z,roffset,                                  
+     &                  a0b0,prec,sb,nu,tinv1,smu,psiinv,tinv2,tau,
+     &                  mcmc,nsave,                                       
+     &                  ncluster,ss,alpha,beta,b,betar,mu,              
+     &                  sigma,sigmainv,mub,sigmab,sigmabinv,v,mc,       
+     &                  acrate,cpo,randsave,thetasave,musave,clustsave, 
+     &                  iflagp,betac,workmhp,workvp,xtx,xty,            
+     &                  iflagr,theta,thetac,workmhr,workmhr2,workmr,    
+     &                  workvr,ztz,zty,cstrt,ccluster,prob,quadf,       
+     &                  seed,betasave,bsave)
 c=======================================================================                      
 c     # of arguments = 65.
 c
@@ -18,7 +18,7 @@ c     Subroutine `dpmglmmgam' to run a Markov chain in a semiparametric
 c     gamma mixed effect model, using a Dirichlet process mixture of 
 c     normals prior for the distribution of the random effects.
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara, 2007-2009
 c
 c     The parametrization considered here is:
 c     log p(Y)= v* ((-1/mu)*Y - log(mu)) + c(Y,v),
@@ -49,16 +49,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -265,7 +265,7 @@ c=======================================================================
 c+++++Data
       integer maxni,nrec,nsubject,nfixed,p,q,subject(nrec)
       integer datastr(nsubject,maxni+1)
-      real*8 roffset(nrec),x(nrec,p),z(nrec,q),y(nrec)	
+      real*8 roffset(nrec),x(nrec,p),z(nrec,q),y(nrec)
       
 c+++++Prior 
       integer nu01,nu02,nu(3) 
@@ -329,7 +329,7 @@ c+++++DPM
 c+++++Kernel
       real*8 quadf(q,q)
 
-c++++ models performance
+c++++ model's performance
       real*8 mc(5)
       real*8 betasave(p+1),bsave(nsubject,q)
 
@@ -364,7 +364,7 @@ c+++++DP (functional parameter)
       real*8 eps,rbeta,weight
       parameter(eps=0.01)
 
-c++++ models performance
+c++++ model's performance
       real*8 dbarc,dbar,dhat,pd,lpml
 
 c+++++dispersion parameter
@@ -388,7 +388,9 @@ c++++ parameters
       nu01=nu(1)
       nu02=nu(2)
       tune4=nu(3)
-      
+      tau1=tau(1)
+      tau2=tau(2)
+
 c++++ set random number generator
       seed1=seed(1)
       seed2=seed(2)
@@ -923,7 +925,7 @@ c++++++++++ subject in cluster with only 1 observation
                if(since.lt.ncluster)then
                    call relabeldpm(i,since,nsubject,q,ncluster,
      &                             ccluster,ss,cstrt)                   
-	       end if
+               end if
 
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
@@ -1330,8 +1332,8 @@ c+++++++++++++ cpo
                         eta=eta+x(i,j)*beta(j)
                      end do
                   end if   
-		  do j=1,q
-		     eta=eta+z(i,j)*b(subject(i),j)
+                  do j=1,q
+                     eta=eta+z(i,j)*b(subject(i),j)
                   end do
                   eta=eta+roffset(i)
                   call dgamma(y(i),exp(eta),v,tmp1) 
@@ -1364,7 +1366,7 @@ c+++++++++++++ print
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                    
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
 
       do i=1,p+1
@@ -1385,8 +1387,8 @@ c+++++++++++++ print
          do j=1,p
             eta=eta+x(i,j)*betasave(j)
          end do
-	 do j=1,q
-	   eta=eta+z(i,j)*bsave(subject(i),j)
+         do j=1,q
+            eta=eta+z(i,j)*bsave(subject(i),j)
          end do
          eta=eta+roffset(i)                  
          
@@ -1410,4 +1412,4 @@ c+++++++++++++ print
       
       return
       end
-         
\ No newline at end of file
+         
