@@ -1,16 +1,16 @@
 c=======================================================================                      
       subroutine dpmglmmpois(
-     &                  maxni,nrec,nsubject,nfixed,p,q,subject,datastr, #8
-     &                  y,x,z,roffset,                                  #4
-     &                  a0b0,prec,sb,nu,tinv1,smu,psiinv,tinv2,         #8
-     &                  mcmc,nsave,                                     #2  
-     &                  ncluster,ss,alpha,beta,b,betar,mu,              #7
-     &                  sigma,sigmainv,mub,sigmab,sigmabinv,mc,         #6
-     &                  acrate,cpo,randsave,thetasave,musave,clustsave, #6
-     &                  iflagp,betac,workmhp,workvp,xtx,xty,            #6
-     &                  iflagr,theta,thetac,workmhr,workmhr2,workmr,    #6
-     &                  workvr,ztz,zty,cstrt,ccluster,prob,quadf,       #7
-     &                  seed,betasave,bsave)                            #3 
+     &                  maxni,nrec,nsubject,nfixed,p,q,subject,datastr, 
+     &                  y,x,z,roffset,                                  
+     &                  a0b0,prec,sb,nu,tinv1,smu,psiinv,tinv2,         
+     &                  mcmc,nsave,                                       
+     &                  ncluster,ss,alpha,beta,b,betar,mu,              
+     &                  sigma,sigmainv,mub,sigmab,sigmabinv,mc,         
+     &                  acrate,cpo,randsave,thetasave,musave,clustsave, 
+     &                  iflagp,betac,workmhp,workvp,xtx,xty,            
+     &                  iflagr,theta,thetac,workmhr,workmhr2,workmr,    
+     &                  workvr,ztz,zty,cstrt,ccluster,prob,quadf,       
+     &                  seed,betasave,bsave)
 c=======================================================================                      
 c     # of arguments = 63.
 c
@@ -18,7 +18,7 @@ c     Subroutine `dpmglmmpois' to run a Markov chain in a semiparametric
 c     poisson mixed effect model, using a Dirichlet process mixture of 
 c     normals prior for the distribution of the random effects.
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara, 2007-2009.
 c
 c     Version 1.0:
 c
@@ -40,16 +40,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -247,7 +247,7 @@ c=======================================================================
 c+++++Data
       integer maxni,nrec,nsubject,nfixed,p,q,subject(nrec)
       integer datastr(nsubject,maxni+1),y(nrec)
-      real*8 roffset(nrec),x(nrec,p),z(nrec,q)	
+      real*8 roffset(nrec),x(nrec,p),z(nrec,q)
       
 c+++++Prior 
       integer nu01,nu02,nu(2) 
@@ -842,7 +842,7 @@ c++++++++++ subject in cluster with only 1 observation
                if(since.lt.ncluster)then
                    call relabeldpm(i,since,nsubject,q,ncluster,
      &                             ccluster,ss,cstrt)                   
-	       end if
+               end if
 
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
@@ -1245,8 +1245,8 @@ c+++++++++++++ cpo
                         eta=eta+x(i,j)*beta(j)
                      end do
                   end if   
-		  do j=1,q
-		     eta=eta+z(i,j)*b(subject(i),j)
+                  do j=1,q
+                     eta=eta+z(i,j)*b(subject(i),j)
                   end do
                   eta=eta+roffset(i)               
                   mean=exp(eta)
@@ -1283,7 +1283,7 @@ c+++++++++++++ print
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                    
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
 
       do i=1,p
@@ -1304,8 +1304,8 @@ c+++++++++++++ print
          do j=1,p
             eta=eta+x(i,j)*betasave(j)
          end do
-	 do j=1,q
-	   eta=eta+z(i,j)*bsave(subject(i),j)
+         do j=1,q
+            eta=eta+z(i,j)*bsave(subject(i),j)
          end do
          eta=eta+roffset(i)                  
          
@@ -1327,4 +1327,4 @@ c+++++++++++++ print
       
       return
       end
-         
\ No newline at end of file
+         
