@@ -1,17 +1,17 @@
 
 c=======================================================================                      
       subroutine dpmglmmprob(                                            
-     &                  maxni,nrec,nsubject,nfixed,p,q,subject,datastr, #8
-     &                  yr,x,z,xtx,                                     #4
-     &                  a0b0,prec,sb,nu,tinv1,smu,psiinv,tinv2,         #8
-     &                  mcmc,nsave,                                     #2  
-     &                  ncluster,ss,alpha,beta,b,betar,mu,              #7
-     &                  sigma,sigmainv,mub,sigmab,sigmabinv,mc,         #6
-     &                  cpo,randsave,thetasave,musave,clustsave,        #5
-     &                  iflagp,workmhp,workmp,workvp,xty,               #5
-     &                  iflagr,theta,workmhr,workmhr2,workmr,workvr,    #6
-     &                  ztz,zty,cstrt,ccluster,prob,quadf,y,            #7
-     &                  seed,betasave,bsave)                            #3 
+     &                  maxni,nrec,nsubject,nfixed,p,q,subject,datastr, 
+     &                  yr,x,z,xtx,                                     
+     &                  a0b0,prec,sb,nu,tinv1,smu,psiinv,tinv2,         
+     &                  mcmc,nsave,                                      
+     &                  ncluster,ss,alpha,beta,b,betar,mu,              
+     &                  sigma,sigmainv,mub,sigmab,sigmabinv,mc,         
+     &                  cpo,randsave,thetasave,musave,clustsave,        
+     &                  iflagp,workmhp,workmp,workvp,xty,               
+     &                  iflagr,theta,workmhr,workmhr2,workmr,workvr,    
+     &                  ztz,zty,cstrt,ccluster,prob,quadf,y,            
+     &                  seed,betasave,bsave)                            
 c=======================================================================                      
 c     # of arguments = 61.
 c
@@ -19,7 +19,7 @@ c     Subroutine `dpmglmmprob' to run a Markov chain in a semiparametric
 c     probit mixed effect model, using a Dirichlet process mixture of 
 c     normals prior for the distribution of the random effects.
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara, 2007-2009.
 c
 c     Version 1.0:
 c
@@ -41,16 +41,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -249,7 +249,7 @@ c=======================================================================
 c+++++Data
       integer maxni,nrec,nsubject,nfixed,p,q,subject(nrec)
       integer datastr(nsubject,maxni+1),yr(nrec)
-      real*8 x(nrec,p),z(nrec,q),xtx(p,p)	
+      real*8 x(nrec,p),z(nrec,q),xtx(p,p)
 
 c+++++Prior 
       integer nu01,nu02,nu(2) 
@@ -622,7 +622,7 @@ c++++++++++ subject in cluster with only 1 observation
                if(since.lt.ncluster)then
                    call relabeldpm(i,since,nsubject,q,ncluster,
      &                             ccluster,ss,cstrt)                   
-	       end if
+               end if
 
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
@@ -1030,8 +1030,8 @@ c+++++++++++++ cpo
                         tmp1=tmp1+x(i,j)*beta(j) 
                      end do
                   end if   
-		  do j=1,q
-		     tmp1=tmp1+z(i,j)*b(subject(i),j)
+                  do j=1,q
+                     tmp1=tmp1+z(i,j)*b(subject(i),j)
                   end do
                   
                   tmp1=cdfnorm(tmp1,0.d0,1.d0,1,0)
@@ -1064,7 +1064,7 @@ c+++++++++++++ print
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                    
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
 
       do i=1,p
@@ -1084,8 +1084,8 @@ c+++++++++++++ print
          do j=1,p
             tmp1=tmp1+x(i,j)*betasave(j)
          end do
-	 do j=1,q
-	   tmp1=tmp1+z(i,j)*bsave(subject(i),j)
+         do j=1,q
+            tmp1=tmp1+z(i,j)*bsave(subject(i),j)
          end do
 
          tmp1=cdfnorm(tmp1,0.d0,1.d0,1,0)
