@@ -1,24 +1,24 @@
 
 c=======================================================================                      
-      subroutine dpmlmm(maxni,nrec,nsubject,nfixed,p,q,subject,datastr, #8
-     &                  y,x,z,xtx,                                      #4
-     &                  a0b0,prec,sb,tau,nu,tinv1,smu,psiinv,tinv2,     #9
-     &                  mcmc,nsave,                                     #2  
-     &                  ncluster,ss,alpha,beta,b,betar,mu,sigma2e,      #8
-     &                  sigma,sigmainv,mub,sigmab,sigmabinv,mc,         #6
-     &                  cpo,randsave,thetasave,musave,clustsave,        #5
-     &                  iflagp,workmhp,workmp,workvp,xty,               #5
-     &                  iflagr,theta,workmhr,workmhr2,workmr,workvr,    #6
-     &                  ztz,zty,cstrt,ccluster,prob,quadf,              #6
-     &                  seed,betasave,bsave)                            #3 
-c=======================================================================                      
+      subroutine dpmlmm(maxni,nrec,nsubject,nfixed,p,q,subject,datastr, 
+     &                  y,x,z,xtx,                                      
+     &                  a0b0,prec,sb,tau,nu,tinv1,smu,psiinv,tinv2,     
+     &                  mcmc,nsave,                                       
+     &                  ncluster,ss,alpha,beta,b,betar,mu,sigma2e,      
+     &                  sigma,sigmainv,mub,sigmab,sigmabinv,mc,         
+     &                  cpo,randsave,thetasave,musave,clustsave,        
+     &                  iflagp,workmhp,workmp,workvp,xty,               
+     &                  iflagr,theta,workmhr,workmhr2,workmr,workvr,    
+     &                  ztz,zty,cstrt,ccluster,prob,quadf,              
+     &                  seed,betasave,bsave)
+c=======================================================================
 c     # of arguments = 63.
 c
 c     Subroutine `dpmlmm' to run a Markov chain in a semiparametric 
 c     linear mixed effect model, using a Dirichlet process mixture of 
 c     normals prior for the distribution of the random effects.
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara, 2007-2009
 c
 c     Version 1.0:
 c
@@ -40,16 +40,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -251,7 +251,7 @@ c=======================================================================
 c+++++Data
       integer maxni,nrec,nsubject,nfixed,p,q,subject(nrec)
       integer datastr(nsubject,maxni+1)
-      real*8 y(nrec),x(nrec,p),z(nrec,q),xtx(p,p)	
+      real*8 y(nrec),x(nrec,p),z(nrec,q),xtx(p,p)
 
 c+++++Prior 
       integer nu01,nu02,nu(2) 
@@ -622,7 +622,7 @@ c++++++++++ subject in cluster with only 1 observation
                if(since.lt.ncluster)then
                    call relabeldpm(i,since,nsubject,q,ncluster,
      &                             ccluster,ss,cstrt)                   
-	       end if
+               end if
 
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
@@ -987,7 +987,7 @@ c+++++++++++++ regression coefficients
                if(nfixed.gt.0)then
                   do i=1,p
                      thetasave(isave,q+i)=beta(i)
-                     betasave(i)=betasave(i)+beta(i)                     
+                     betasave(i)=betasave(i)+beta(i)
                   end do
                end if   
 
@@ -1065,7 +1065,7 @@ c+++++++++++++ print
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                    
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
 
       do i=1,p+1
