@@ -1,15 +1,15 @@
 
 c=======================================================================                      
-      subroutine dpmmeta(nrec,nfixed,p,                                 #3
-     &                   y,x,sigma2e,                                   #3
-     &                   a0b0,prec,sb,tau,smu,psiinv,                   #6
-     &                   mcmc,nsave,                                    #2  
-     &                   ncluster,ss,alpha,beta,b,mu,                   #6
-     &                   sigma,mub,sigmab,mc,                           #4
-     &                   cpo,randsave,thetasave,musave,clustsave,       #5
-     &                   iflagp,workmhp,workmp,workvp,xty,              #5
-     &                   cstrt,ccluster,prob,                           #3
-     &                   seed,betasave,bsave)                           #3 
+      subroutine dpmmeta(nrec,nfixed,p,                                 
+     &                   y,x,sigma2e,                                   
+     &                   a0b0,prec,sb,tau,smu,psiinv,                   
+     &                   mcmc,nsave,                                     
+     &                   ncluster,ss,alpha,beta,b,mu,                   
+     &                   sigma,mub,sigmab,mc,                           
+     &                   cpo,randsave,thetasave,musave,clustsave,       
+     &                   iflagp,workmhp,workmp,workvp,xty,              
+     &                   cstrt,ccluster,prob,                           
+     &                   seed,betasave,bsave)                           
 c=======================================================================                      
 c     # of arguments = 40.
 c
@@ -17,7 +17,7 @@ c     Subroutine `dpmmeta' to run a Markov chain in the semiparametric
 c     meta-analytic linear mixed model using a Dirichlet Process Mixture
 c     of normals prior for the distributions of the random effecs. 
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara, 2007-2009.
 c
 c     Version 1.0:
 c
@@ -39,16 +39,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -459,7 +459,7 @@ c++++++++++ subject in cluster with only 1 observation
                if(since.lt.ncluster)then
                    call relabeldpm(i,since,nrec,1,ncluster,
      &                             ccluster,ss,cstrt)                   
-	       end if
+               end if
 
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
@@ -673,7 +673,7 @@ c+++++++++++++ regression coefficients
                if(nfixed.gt.0)then
                   do i=1,p
                      thetasave(isave,1+i)=beta(i)
-                     betasave(i)=betasave(i)+beta(i)                     
+                     betasave(i)=betasave(i)+beta(i)
                   end do
                end if   
 
@@ -727,7 +727,7 @@ c+++++++++++++ print
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                    
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
 
       do i=1,p
