@@ -1,32 +1,30 @@
 c=======================================================================                      
-      subroutine dpdenregr(nrec,nx,nvar,nmissi,nmiss,z,missp,npred,     #8
-     &                     xpred,ngrid,grid,                            #3
-     &                     a0b0,k0,nuvec,m1rand,s2inv,                  #5
-     &                     s2invm2,                                     #1 
-     &                     psiinv2,tau,mcmc,nsave,                      #4
-     &                     cpo,thetasave,meansave,denspm,denspl,densph, #6
-     &                     meanfpm,meanfpl,meanfph,                     #3
-     &                     alpha,m1,muclus,ncluster,                    #4
-     &                     psi1,psiinv1,s1,sigmaclus,ss,ccluster,cstrt, #7
-     &                     iflag,num,denom,fs,fm,                       #5
-     &                     muwork,prob,seed,sigmawork,sigworkinv,theta, #6
-     &                     workm1,workm2,workm3,workmh1,workmh2,workv1, #6
-     &                     workv2,workv3,ywork,                         #3
-     &                     iflagx,workvx,workmx,worksam)                #4
+      subroutine dpdenregr(nrec,nx,nvar,nmissi,nmiss,z,missp,npred,
+     &                     xpred,ngrid,grid,  
+     &                     a0b0,k0,nuvec,s2inv, 
+     &                     s2invm2, 
+     &                     psiinv2,tau,mcmc,nsave,
+     &                     cpo,thetasave,denspm,denspl,densph, 
+     &                     meanfpm,meanfpl,meanfph, 
+     &                     alpha,m1,muclus,ncluster,
+     &                     psi1,psiinv1,s1,sigmaclus,ss,ccluster,cstrt,
+     &                     iflag,num,denom,fs,fm, 
+     &                     muwork,prob,seed,sigmawork,sigworkinv,theta,
+     &                     workm1,workm2,workm3,workmh1,workmh2,workv1,
+     &                     workv2,workv3,ywork,
+     &                     iflagx,workvx,workmx,worksam,
+     &                     numcpo,denomcpo)
 c=======================================================================                      
-c     # of arguments = 64.
+c     # of arguments = 63.
 c
 c     Subroutine `dpdenregr' to run a Markov chain in the DP mixture of  
 c     normals model for conditional density estimation. 
 c
 c     In this routine, inference is based on the 
 c     Polya urn representation of the Dirichlet process. The algorithm
-c     8 of Neal (2000) is used with m=1. The difference with respect to
-c     `spdenn` is that this includes a grid of points where the density
-c     estimate is evaluated. This fucntion can be used only for dimension
-c     <=2.
+c     8 of Neal (2000) is used with m=1. 
 c
-c     Copyright: Alejandro Jara, 2008
+c     Copyright: Alejandro Jara, 2008-2009.
 c
 c     Version 1.0: 
 c
@@ -48,16 +46,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafaël
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -284,7 +282,7 @@ c+++++Prediction
       real*8 grid(ngrid) 
 
 c+++++Prior 
-      integer nuvec(2),nu1,nu2,m1rand
+      integer nuvec(3),nu1,nu2,m1rand
       real*8 aa0,ab0,a0b0(2)
       real*8 psiinv2(nvar,nvar)
       real*8 tau(2),tau1,tau2
@@ -296,7 +294,6 @@ c+++++MCMC parameters
 c+++++Output
       real*8 cpo(nrec,2)
       real*8 thetasave(nsave,nvar+nvar*(nvar+1)/2+3)
-      real*8 meansave(nsave,npred)
       real*8 denspm(npred,ngrid)
       real*8 denspl(npred,ngrid)
       real*8 densph(npred,ngrid)
@@ -306,9 +303,9 @@ c+++++Output
 
 c+++++Current values of the parameters
       integer ncluster,ss(nrec)
-      real*8 alpha,k0,m1(nvar),muclus(nrec+2,nvar)
+      real*8 alpha,k0,m1(nvar),muclus(nrec+100,nvar)
       real*8 psi1(nvar,nvar),psiinv1(nvar,nvar)
-      real*8 sigmaclus(nrec+2,nvar*(nvar+1)/2)
+      real*8 sigmaclus(nrec+100,nvar*(nvar+1)/2)
 
 c+++++Seeds
       integer seed(2),seed1,seed2
@@ -320,7 +317,7 @@ c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
       integer cstrt(nrec,nrec)
       integer iflag(nvar)
       integer iflagx(nx)
-      real*8 muwork(nvar),prob(nrec+2)
+      real*8 muwork(nvar),prob(nrec+100)
       real*8 s1(nvar,nvar)
       real*8 sigmawork(nvar,nvar),sigworkinv(nvar,nvar)
       real*8 theta(nvar)
@@ -339,22 +336,25 @@ c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
       real*8 worksam(nsave) 
 
+      real*8 numcpo(nrec),denomcpo(nrec)
+
 c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 c+++++Internal working space
 c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 c+++++General
-      integer count,evali
+      integer counter,evali
       integer i,ii,ihmssf,j,jj,k,l,nuniqs,nuwork,ns,ok 
-      integer since,sprint 
+      integer since,sprint
+      integer isample
 
       real*8 detlog,detlogx
-      real*8 mean,muc,sigmac  
+      real*8 muc,sigmac  
       real*8 tmp1,tmp2,tmp3,tmp4,tmp5,tmp6,tmp7
       real*8 tpi
+      real*8 cpotest
       parameter(tpi=6.283185307179586476925286766559d0)
-      logical ainf,asup      
-
+      
 c+++++MCMC
       integer dispcount,isave,iscan,nscan,skipcount 
 
@@ -383,19 +383,25 @@ c++++ Define parameters
       nuniqs=nvar*(nvar+1)/2
       nu1=nuvec(1)
       nu2=nuvec(2)
+      m1rand=nuvec(3)
 
+      cpotest=0.d0
+      
 c++++ opening files
 
       open(unit=1,file='dppackage1.out',status='unknown',
      &     form='unformatted')
 
+      open(unit=2,file='dppackage2.out',status='unknown',
+     &     form='unformatted')
+
 c++++ set random number generator
 
       seed1=seed(1)
       seed2=seed(2)
 
       call setall(seed1,seed2)
-     
+
 c++++ cluster structure
 
       do i=1,nrec
@@ -406,7 +412,7 @@ c++++ cluster structure
 c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 c++++ start the MCMC algorithm
 c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
+      isample=1
       isave=0
       skipcount=0
       dispcount=0
@@ -422,47 +428,48 @@ c+++++++ Imputing the missing data
 c+++++++++++++++++++++++++++++++++++++++++
 
          if(nmissi.eq.1)then
-         do ii=1,nmiss
 
-            i=missp(ii,1)
-            jj=missp(ii,2)   
+c++++++++++ check if the user has requested an interrupt
+            call rchkusr()
+
+            do ii=1,nmiss
+
+               i=missp(ii,1)
+               jj=missp(ii,2)   
+
+               do j=1,nvar
+                  muwork(j)=muclus(ss(i),j)
+                  do k=1,nvar
+                     sigmawork(j,k)=sigmaclus(ss(i),ihmssf(j,k,nvar))
+                  end do
+               end do                
+
+               call condmvn(jj,sigmawork,nvar,workm1,workm2)
+               tmp1=sqrt(workm1(1,1))
 
-            do j=1,nvar
-               muwork(j)=muclus(ss(i),j)
                do k=1,nvar
-                  sigmawork(j,k)=sigmaclus(ss(i),ihmssf(j,k,nvar))
-               end do
-            end do                
-
-            call condmvn(jj,sigmawork,nvar,workm1,workm2)
-            tmp1=sqrt(workm1(1,1))
-
-            do k=1,nvar
-               tmp2=0.d0
-               do l=1,nvar
-                  tmp2=tmp2+workm2(k,l)*muwork(l) 
-               end do
-               workv2(k)=tmp1
+                  tmp2=0.d0
+                  do l=1,nvar
+                     tmp2=tmp2+workm2(k,l)*muwork(l) 
+                  end do
+                  workv2(k)=tmp2
  
-               tmp2=0.d0
-               do l=1,nvar
-                  tmp2=tmp2+workm2(k,l)*z(i,l) 
+                  tmp2=0.d0
+                  do l=1,nvar
+                     tmp2=tmp2+workm2(k,l)*z(i,l) 
+                  end do
+                  workv3(k)=tmp1
                end do
-               workv3(k)=tmp1
+
+               tmp2=muwork(jj)
+               do k=2,nvar
+                  tmp2=tmp2-workm1(1,k)*(workv3(k)-workv2(k))
+               end do            
+
+               z(i,jj)=rnorm(tmp2,tmp1) 
             end do
-
-            tmp2=muwork(jj)
-            do k=2,nvar
-               tmp2=tmp2-workm1(1,k)*(workv3(k)-workv2(k))
-            end do            
-
-            z(i,jj)=rnorm(tmp2,tmp1) 
-         end do
          end if 
 
-c+++++++ check if the user has requested an interrupt
-         call rchkusr()
-
 c++++++++++++++++++++++++++++++++++         
 c+++++++ DP part
 c++++++++++++++++++++++++++++++++++
@@ -494,6 +501,7 @@ c++++++++++ observation in cluster with more than 1 element
                   cstrt(ss(i),j)=cstrt(ss(i),j+1)
                end do
 
+               isample=1
             end if
 
 c++++++++++ observation in cluster with only 1 element
@@ -502,21 +510,17 @@ c++++++++++ observation in cluster with only 1 element
                 
                since=ss(i)
 
-               do j=since+1,ncluster
-                  do k=1,ccluster(j)  
-                     cstrt(j-1,k)=cstrt(j,k)          
-                  end do
-               end do
-
                if(since.lt.ncluster)then
-                   call relabeld(i,since,nrec,nvar,ncluster,
-     &                           ccluster,ss,muclus,sigmaclus,
-     &                           muwork,sigmawork)                   
-	       end if
+
+                   call relabelddr(i,since,nrec,nvar,ncluster,
+     &                             ccluster,cstrt,ss,muclus,sigmaclus,
+     &                             muwork,sigmawork)                   
+               end if
 
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
 
+               isample=2
             end if
 
 c++++++++++ sampling
@@ -534,47 +538,53 @@ c++++++++++ sampling
                end do                
                    
                call dmvn(nvar,ywork,muwork,sigmawork,tmp1,
-     &                   workv1,workm1,workm2,workv2,iflag)                 
+     &                   workv1,workm1,workm2,workv2,iflag)
 
                prob(j)=exp(log(dble(ccluster(j)))+
      &                     tmp1)
             end do
+            
+            if(isample.eq.1)then
                
-            do k=1,nvar
-               do l=1,nvar
-                  workm3(k,l)=psiinv1(k,l)
+               do k=1,nvar
+                  do l=1,nvar
+                     workm3(k,l)=psiinv1(k,l)
+                  end do
                end do
-            end do
 
-            call riwishart(nvar,nu1,workm3,workm1,workm2,workv1,
-     &                     workmh1,workmh2,iflag)
+               call riwishart(nvar,nu1,workm3,workm1,workm2,workv1,
+     &                        workmh1,workmh2,iflag)
 
-            do k=1,nvar
-               do l=1,nvar
-                  s1(k,l)=workm3(k,l)/dble(k0)
-                  sigmaclus(ncluster+1,ihmssf(k,l,nvar))=
+               do k=1,nvar
+                  do l=1,nvar
+                     s1(k,l)=workm3(k,l)/dble(k0)
+                     sigmaclus(ncluster+1,ihmssf(k,l,nvar))=
      &                      workm3(k,l)
+                  end do
                end do
-            end do
 
-            call rmvnorm(nvar,m1,s1,workmh1,workv1,theta) 
-                  
+               call rmvnorm(nvar,m1,s1,workmh1,workv1,theta) 
+   
+               do k=1,nvar
+                  muclus(ncluster+1,k)=theta(k)
+               end do  
+            end if
+
             do k=1,nvar
-               muclus(ncluster+1,k)=theta(k)
-               muwork(k)=muclus(ncluster+1,k)
-               do l=1,nvar
+                  muwork(k)=muclus(ncluster+1,k)
+                  do l=1,nvar
                   sigmawork(k,l)=
      &                     sigmaclus(ncluster+1,ihmssf(k,l,nvar))
                end do
             end do      
 
             call dmvn(nvar,ywork,muwork,sigmawork,tmp1,
-     &                workv1,workm1,workm2,workv2,iflag)                 
+     &                workv1,workm1,workm2,workv2,iflag)
                    
             prob(ncluster+1)=exp(log(alpha)+
      &                           tmp1)
                
-            call simdisc(prob,nrec+2,ncluster+1,evali)
+            call simdisc(prob,nrec+100,ncluster+1,evali)
                
                
             if(evali.le.ncluster)then
@@ -589,16 +599,17 @@ c++++++++++ sampling
                ccluster(ncluster)=1
                cstrt(ncluster,ccluster(ncluster))=i
                do j=1,nvar
-	          muclus(ncluster,j)=muclus(evali,j)
-	          do k=j,nvar
+                  muclus(ncluster,j)=muclus(evali,j)
+                  do k=j,nvar
                      sigmaclus(ncluster,ihmssf(j,k,nvar))=
      &                         sigmaclus(evali,ihmssf(j,k,nvar))
-	          end do
-	       end do
+                  end do
+               end do
             end if               
 
          end do
 
+
 c++++++++++++++++++++++++++++++
 c+++++++ b) Resampling step
 c++++++++++++++++++++++++++++++
@@ -686,6 +697,7 @@ c++++++++++ cluster's means and variances
             end do
          end do   
 
+
 c++++++++++++++++++++++++++++++++++         
 c+++++++ Baseline distribution
 c++++++++++++++++++++++++++++++++++
@@ -827,7 +839,7 @@ c+++++++ k0
 
                do j=1,nvar
                   do k=1,nvar
-                     tmp1=tmp1+ywork(j)*sigworkinv(j,k)*ywork(k)                
+                     tmp1=tmp1+ywork(j)*sigworkinv(j,k)*ywork(k)
                   end do
                end do
             end do   
@@ -850,51 +862,49 @@ c++++++++++++++++++++++++++++++++++
 c+++++++ save samples
 c++++++++++++++++++++++++++++++++++         
 
-c         call intpr("Step 4",-1,0,1)
-         
          if(iscan.gt.nburn)then
             skipcount=skipcount+1
             if(skipcount.gt.nskip)then
                isave=isave+1
                dispcount=dispcount+1
 
-               count=0
+               counter=0
 
 c+++++++++++++ normal baseline mean
 
                do i=1,nvar
-                  count=count+1
-                  thetasave(isave,count)=m1(i)
+                  counter=counter+1
+                  thetasave(isave,counter)=m1(i)
                end do   
 
 c+++++++++++++ k0 parameter
 
-               count=count+1
-               thetasave(isave,count)=k0
+               counter=counter+1
+               thetasave(isave,counter)=k0
 
 c+++++++++++++ IW baseline scale
 
                do i=1,nvar
                   do j=i,nvar
-                     count=count+1
-                     thetasave(isave,count)=psi1(i,j)
+                     counter=counter+1
+                     thetasave(isave,counter)=psi1(i,j)
                   end do
                end do
  
 c+++++++++++++ cluster information
                
-               count=count+1
-               thetasave(isave,count)=ncluster
-               count=count+1
-               thetasave(isave,count)=alpha               
-
+               counter=counter+1
+               thetasave(isave,counter)=ncluster
+               counter=counter+1
+               thetasave(isave,counter)=alpha   
+               
 c+++++++++++++ Partially sampling the DP and computing the cond. dist.
 
                do i=1,ncluster
                   prob(i)=dble(ccluster(i))/(alpha+dble(nrec))
                end do
                prob(ncluster+1)=alpha/(alpha+dble(nrec))
-               call simdisc(prob,nrec+2,ncluster+1,evali)
+               call simdisc(prob,nrec+100,ncluster+1,evali)
 
                if(evali.le.ncluster)then
                   do i=1,nvar  
@@ -942,6 +952,7 @@ c+++++++++++++ Partially sampling the DP and computing the cond. dist.
                weight=(1.d0-tmp1)
 
                do i=1,npred  
+                  call rchkusr()
                   muc=muwork(1)
                   do k=2,nvar
                      muc=muc-workm1(1,k)*(xpred(i,k-1)-muwork(k))
@@ -963,9 +974,11 @@ c+++++++++++++ Partially sampling the DP and computing the cond. dist.
                   end do 
                   denom(i)=tmp1*tmp7
                   fm(i)=tmp1*tmp7*muc
-              end do
+               end do
 
                do while((1.d0-tmp2).gt.eps)
+                  call rchkusr()
+
                   tmp3=rbeta(1.d0,alpha+dble(nrec))
                   tmp1=weight*tmp3
                   weight=weight*(1.d0-tmp3)
@@ -1016,6 +1029,7 @@ c+++++++++++++ Partially sampling the DP and computing the cond. dist.
                   sigmac=sqrt(workm1(1,1))
 
                   do i=1,npred  
+                     call rchkusr()
                      muc=muwork(1)
                      do k=2,nvar
                         muc=muc-workm1(1,k)*(xpred(i,k-1)-muwork(k))
@@ -1044,35 +1058,110 @@ c+++++++++++++ Partially sampling the DP and computing the cond. dist.
                end do
 
                do i=1,npred
+                  call rchkusr()
+
                   fm(i)=fm(i)/denom(i)
                   meanfpm(i)=meanfpm(i)+fm(i) 
-                  meansave(isave,i)=fm(i) 
                   do j=1,ngrid
                      fs(j)=num(i,j)/denom(i)
                      denspm(i,j)=denspm(i,j)+fs(j)
                   end do
                   write(1) (fs(j),j=1,ngrid)
-                  write(2) (fm(j),j=1,npred)
                end do 
-
-c+++++++++++++ cpo
-               do i=1,nrec
-                  do j=1,nvar  
-                     ywork(j)=z(i,j)
-                     muwork(j)=muclus(ss(i),j)
-                     do k=1,nvar
-                        sigmawork(j,k)=sigmaclus(ss(i),
-     &                                 ihmssf(j,k,nvar))
-                     end do
-                  end do  
-                     
-                  call dmvn(nvar,ywork,muwork,sigmawork,tmp1,
-     &                      workv1,workm1,workm2,workv2,iflag)                 
+               write(2) (fm(j),j=1,npred)
  
-                  tmp1=exp(tmp1)
-                  cpo(i,1)=cpo(i,1)+1.0d0/tmp1
-                  cpo(i,2)=cpo(i,2)+tmp1                  
+c+++++++++++++ cpo
+
+               do i=1,ncluster
+                  prob(i)=dble(ccluster(i))/(alpha+dble(nrec))
                end do
+               do i=ncluster+1,ncluster+100
+                  prob(i)=alpha/(100.d0*(alpha+dble(nrec)))
+               end do   
+               call simdisc(prob,nrec+100,ncluster+100,evali)
+
+               do i=ncluster+1,ncluster+100
+                  do k=1,nvar
+                     do l=1,nvar
+                        workm3(k,l)=psiinv1(k,l)
+                     end do
+                  end do
+
+                  call riwishart(nvar,nu1,workm3,workm1,workm2,
+     &                           workv1,workmh1,workmh2,iflag)
+                  do k=1,nvar
+                     do l=1,nvar
+                        s1(k,l)=workm3(k,l)/dble(k0)
+                        sigmaclus(i,ihmssf(k,l,nvar))=workm3(k,l)
+                     end do
+                  end do
+                  call rmvnorm(nvar,m1,s1,workmh1,workv1,theta) 
+                  do k=1,nvar
+                     muclus(i,k)=theta(k)
+                  end do      
+               end do
+
+               do i=1,nrec
+                  numcpo(i)=0.d0
+                  denomcpo(i)=0.d0
+               end do   
+
+               do ii=1,ncluster+100
+     
+                  do j=1,nvar
+                     muwork(j)=muclus(ii,j)
+                     do k=1,nvar
+                        sigmawork(j,k)=
+     &                         sigmaclus(ii,ihmssf(j,k,nvar))
+                     end do
+                  end do                
+
+                  do j=2,nvar
+                     workvx(j-1)=muwork(j)
+                     do k=2,nvar
+                        workmx(j-1,k-1)=sigmawork(j,k)         
+                     end do  
+                  end do   
+                  call inversedet(workmx,nx,iflagx,detlogx)
+
+                  call condmvn(1,sigmawork,nvar,workm1,workm2)
+                  sigmac=sqrt(workm1(1,1))
+
+                  do i=1,nrec    
+                     call rchkusr()
+                     muc=muwork(1)
+                     do k=2,nvar
+                        muc=muc-workm1(1,k)*(z(i,k)-muwork(k))
+                     end do            
+
+                     tmp4=-(dble(nx)*log(tpi))
+                     tmp5=0.d0  
+                     do j=1,nx
+                        do k=1,nx
+                           tmp5=tmp5+(z(i,j+1)-workvx(j))*
+     &                       workmx(j,k)*(z(i,k+1)-workvx(k))
+                        end do
+                     end do
+                     tmp6=(tmp4-detlogx-tmp5)/2.d0
+                     tmp7=exp(tmp6)
+
+                     numcpo(i)=numcpo(i)+
+     &                   prob(ii)*dnrm(z(i,1),muc,sigmac,0,0)*tmp7
+                     denomcpo(i)=denomcpo(i)+prob(ii)*tmp7
+                     
+                  end do
+               end do
+                
+               tmp2=0.d0
+               do i=1,nrec
+                  tmp3=numcpo(i)/denomcpo(i)
+                  cpo(i,1)=cpo(i,1)+1.0d0/tmp3  
+                  cpo(i,2)=cpo(i,2)+tmp3                   
+
+                  tmp2=tmp2+log(dble(isave)/cpo(i,1))
+               end do
+
+c               call dblepr("LPML",-1,tmp2,1)
 
 c+++++++++++++ print
                skipcount = 0
@@ -1089,11 +1178,14 @@ c+++++++++++++ print
       end do 
 
       do i=1,nrec
+         call rchkusr()
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                             
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
-
+ 
       do i=1,npred
+         call rchkusr()
+
          meanfpm(i)=meanfpm(i)/dble(nsave)
          do j=1,ngrid
             denspm(i,j)= denspm(i,j)/dble(nsave)
@@ -1101,18 +1193,20 @@ c+++++++++++++ print
       end do
 
       close(unit=1)
+      close(unit=2)
 
       call hpddensreg(nsave,npred,ngrid,0.05d0,1,
      &                worksam,fs,denspl,densph)
 
-      call hpddensregmf(nsave,npred,meansave,0.05d0,1,
+      call hpddensregmf(nsave,npred,0.05d0,1,
      &                  worksam,meanfpl,meanfph)
       
       return
       end
 
+
 c=======================================================================      
-      subroutine hpddensregmf(nsave,npred,meansave,alpha,tint,
+      subroutine hpddensregmf(nsave,npred,alpha,tint,
      &                        worksam,llower,lupper)
 c=======================================================================
 c     Compute CI for the conditional means.
@@ -1127,44 +1221,63 @@ c+++++External parameters
       real*8 alpha
 
 c+++++External working
-      real*8 meansave(nsave,npred)
       real*8 worksam(nsave)
 
 c+++++Output      
       real*8 llower(npred)
       real*8 lupper(npred)
 
-c+++++Internal parameters
+c+++++Internal working
+      integer maxnsave,maxnpred
+      parameter(maxnsave=30000,maxnpred=500)
       real*8 aupp(2),alow(2)
+      real*8 workm(maxnsave,maxnpred)
 
 c+++++Internal working
-      integer i,j   
+      integer i,ii,j   
 
 c+++++algorithm
 
-      do i=1,npred
-         do j=1,nsave
-            worksam(j)=meansave(j,i) 
-         end do
+      if(maxnsave.lt.nsave)then
+         call rexit("Increase 'maxnsave' in 'hpddensreg'")
+      end if   
+
+      if(maxnpred.lt.npred)then
+         call rexit("Increase 'maxnpred' in 'hpddensreg'")
+      end if   
+
+      open(unit=2,file='dppackage2.out',status='old',
+     &     form='unformatted')
+
+      do i=1,nsave
+         read(2) (workm(i,j),j=1,npred)
+      end do
+
+      do ii=1,npred
+         do i=1,nsave 
+            call rchkusr()
+            worksam(i)=workm(i,ii)
+         end do  
           
          call hpd(nsave,alpha,worksam,alow,aupp)
           
          if(tint.eq.1)then
 c               (alow(1),aupp(1)): 100(1-alpha)% HPD interval
 c 
-            llower(i)=alow(1)
-            lupper(i)=aupp(1)
+            llower(ii)=alow(1)
+            lupper(ii)=aupp(1)
 
            else
 c              (alow(2),aupp(2)): 100(1-alpha)% Bayesian credible 
 c              interval
 
-            llower(i)=alow(2)
-            lupper(i)=aupp(2)
+            llower(ii)=alow(2)
+            lupper(ii)=aupp(2)
          end if
 
       end do
 
+      close(unit=2)      
       return
       end
 
@@ -1197,7 +1310,7 @@ c+++++Internal parameters
       real*8 workm(maxnsave,maxngrid)
 
 c+++++Internal working
-      integer i,ii,j,jj,k,l   
+      integer i,ii,j,l   
 
 c+++++algorithm
 
@@ -1254,3 +1367,68 @@ c              interval
       close(unit=1)      
       return
       end
+
+
+c=======================================================================      
+      subroutine relabelddr(ind,since,nrec,nvar,ncluster,ccluster,cstrt,
+     &                      ss,muclus,sigmaclus,muwork,sigmawork)
+c=======================================================================
+c     relabel the clusters after the elimination of one of them
+c     A.J.V., 2006
+      implicit none
+      integer dimen,i,ihmssf,j
+      integer ind,since,nrec,nvar,ncluster,ccluster(nrec)
+      integer cstrt(nrec,nrec)
+      integer ss(nrec)
+      real*8 muclus(nrec+100,nvar),sigmaclus(nrec+100,nvar*(nvar+1)/2)
+      real*8 muwork(nvar),sigmawork(nvar,nvar)
+
+      integer ns,ii  
+      dimen=nvar*(nvar+1)/2
+
+      do i=1,nvar
+         muwork(i)=muclus(since,i)
+         do j=1,nvar
+            sigmawork(i,j)=sigmaclus(since,ihmssf(i,j,nvar))
+         end do
+      end do
+      
+      do i=since+1,ncluster
+
+         ns=ccluster(i)    
+         
+         do j=1,ns
+c++++++++++ check if the user has requested an interrupt
+            call rchkusr()
+            ii=cstrt(i,j) 
+            ss(ii)=i-1
+         end do
+
+         do j=1,ns
+            cstrt(i-1,j)=cstrt(i,j) 
+         end do
+
+         do j=1,nvar
+            muclus(i-1,j)=muclus(i,j)
+         end do
+         do j=1,dimen
+            sigmaclus(i-1,j)=sigmaclus(i,j)
+         end do
+         
+         ccluster(i-1)=ccluster(i)
+      end do
+      
+      ss(ind)=ncluster
+      
+      do i=1,nvar
+         muclus(ncluster,i)=muwork(i)
+         do j=i,nvar
+             sigmaclus(ncluster,ihmssf(i,j,nvar))=sigmawork(i,j)
+         end do
+      end do
+      
+      ccluster(ncluster)=1
+      
+      return
+      end  
+            
