@@ -1,17 +1,17 @@
 
 c=======================================================================                      
-      subroutine dpglmmprob(datastr,maxni,nrec,nsubject,nfixed,p,q,     #6
-     &                      subject,x,xtx,y,yr,z,                       #6
-     &                      a0b0,nu0,prec,psiinv,sb,smu,                #6
-     &                      tinv,mcmc,nsave,randsave,thetasave,cpo,     #6
-     &                      alpha,b,bclus,beta,betar,mu,ncluster,       #7
-     &                      sigma,ss,mc,ccluster,cstrt,                 #5
-     &                      iflag,iflag2,iflagb,prob,quadf,res,seed,    #7
-     &                      sigmainv,theta,work1,workb1,workb2,         #5
-     &                      workmh1,workmh2,workmh3,workk1,workkv1,     #5
-     &                      workkm1,workkm2,workv1,workvb1,             #4
-     &                      workvb2,xty,ywork,zty,ztz,                  #5
-     &                      betasave,bsave)                             #2
+      subroutine dpglmmprob(datastr,maxni,nrec,nsubject,nfixed,p,q,     
+     &                      subject,x,xtx,y,yr,z,                       
+     &                      a0b0,nu0,prec,psiinv,sb,smu,                
+     &                      tinv,mcmc,nsave,randsave,thetasave,cpo,     
+     &                      alpha,b,bclus,beta,betar,mu,ncluster,       
+     &                      sigma,ss,mc,ccluster,cstrt,                 
+     &                      iflag,iflag2,iflagb,prob,quadf,res,seed,    
+     &                      sigmainv,theta,work1,workb1,workb2,         
+     &                      workmh1,workmh2,workmh3,workk1,workkv1,     
+     &                      workkm1,workkm2,workv1,workvb1,             
+     &                      workvb2,xty,ywork,zty,ztz,                  
+     &                      betasave,bsave)                             
 c=======================================================================                      
 c     # of arguments = 65.
 c
@@ -20,7 +20,7 @@ c     probit mixed model using a Dirichlet process prior for the
 c     distribution of the random effects. In this routine, inference is 
 c     based on the Polya urn representation of Dirichlet process.
 c
-c     Copyright: Alejandro Jara, 2006-2007
+c     Copyright: Alejandro Jara, 2006-2009.
 c
 c     Version 2.0: 
 c
@@ -50,16 +50,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -256,8 +256,8 @@ c=======================================================================
 c+++++Data
       integer maxni,nrec,nsubject,nfixed,p,q,subject(nrec)
       integer datastr(nsubject,maxni+1),yr(nrec)
-      real*8 y(nrec),x(nrec,p),z(nrec,q),xtx(p,p)	
-      
+      real*8 y(nrec),x(nrec,p),z(nrec,q),xtx(p,p)
+
 c+++++Prior 
       integer nu0,murand,sigmarand
       real*8 aa0,ab0,a0b0(2),prec(p,p),psiinv(q,q)
@@ -571,7 +571,7 @@ c++++++++++ subject in cluster with more than 1 observations
                tmp3=0.d0
                do j=1,ni
                   do k=1,ni
-                     tmp3=tmp3+ywork(j)*workkm2(j,k)*ywork(k)                  
+                     tmp3=tmp3+ywork(j)*workkm2(j,k)*ywork(k)
                   end do
                end do
                
@@ -593,7 +593,7 @@ c++++++++++ subject in cluster with more than 1 observations
                         tmp1=0.d0
                         do l=1,ni
                            tmp1=tmp1+z(datastr(i,l+1),j)*
-     &                          z(datastr(i,l+1),k)                           
+     &                          z(datastr(i,l+1),k)
                         end do
                         ztz(j,k)=tmp1
                      end do
@@ -650,8 +650,8 @@ c++++++++++ subject in cluster with only 1 observation
 
                if(since.lt.ncluster)then
                    call relabel(i,since,nsubject,q,ncluster,
-     &                          cstrt,ccluster,ss,bclus,theta)                   
-	       end if
+     &                          cstrt,ccluster,ss,bclus,theta)
+               end if
                 
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
@@ -718,7 +718,7 @@ c++++++++++ subject in cluster with only 1 observation
                tmp3=0.d0
                do j=1,ni
                   do k=1,ni
-                     tmp3=tmp3+ywork(j)*workkm2(j,k)*ywork(k)                  
+                     tmp3=tmp3+ywork(j)*workkm2(j,k)*ywork(k)
                   end do
                end do
                
@@ -741,7 +741,7 @@ c++++++++++ subject in cluster with only 1 observation
                         tmp1=0.d0
                         do l=1,ni
                            tmp1=tmp1+z(datastr(i,l+1),j)*
-     &                          z(datastr(i,l+1),k)                           
+     &                          z(datastr(i,l+1),k)
                         end do
                         ztz(j,k)=tmp1
                      end do
@@ -819,7 +819,7 @@ c++++++++++ check if the user has requested an interrupt
                      tmp1=0.d0
                      do l=1,ni
                         tmp1=tmp1+z(datastr(cstrt(ii,i),l+1),j)*
-     &                            z(datastr(cstrt(ii,i),l+1),k)                           
+     &                            z(datastr(cstrt(ii,i),l+1),k)
                      end do
                      ztz(j,k)=ztz(j,k)+tmp1
                   end do
@@ -933,7 +933,7 @@ c+++++++ check if the user has requested an interrupt
                do j=1,q
                   do k=1,q
                      quadf(j,k)=quadf(j,k)+               
-     &                          (bclus(i,j)-mu(j))*(bclus(i,k)-mu(k))                   
+     &                          (bclus(i,j)-mu(j))*(bclus(i,k)-mu(k))
                   end do
                end do
             end do
@@ -1076,7 +1076,7 @@ c+++++++++++++ regression coefficients
                if(nfixed.gt.0)then
                   do i=1,p
                      thetasave(isave,q+i)=beta(i)
-                     betasave(i)=betasave(i)+beta(i)                     
+                     betasave(i)=betasave(i)+beta(i)
                   end do
                end if   
 
@@ -1110,8 +1110,8 @@ c+++++++++++++ cpo
                         tmp1=tmp1+x(i,j)*beta(j) 
                      end do
                   end if   
-		  do j=1,q
-		     tmp1=tmp1+z(i,j)*b(subject(i),j)
+                  do j=1,q
+                     tmp1=tmp1+z(i,j)*b(subject(i),j)
                   end do
                   
                   tmp1=cdfnorm(tmp1,0.d0,1.d0,1,0)
@@ -1144,7 +1144,7 @@ c+++++++++++++ print
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                    
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
             
       do i=1,p
@@ -1164,8 +1164,8 @@ c+++++++++++++ print
          do j=1,p
             tmp1=tmp1+x(i,j)*betasave(j)
          end do
-	 do j=1,q
-	   tmp1=tmp1+z(i,j)*bsave(subject(i),j)
+         do j=1,q
+            tmp1=tmp1+z(i,j)*bsave(subject(i),j)
          end do
 
          tmp1=cdfnorm(tmp1,0.d0,1.d0,1,0)
