@@ -1,26 +1,26 @@
-    
+  
 c=======================================================================                      
       subroutine psgamgam
-     &                (nrec,nfixed,p,nsmooth,q,starts,ends,nsmooths,    #8 
-     &                 maxq,x,z,y,roffset,ngrid,znew,zmean,xreal,possfp,#10
-     &                 bet0,prec,sb,taub,iapm,japm,apm,nznh,pordv,      #9
-     &                 tau,                                             #1 
-     &                 beta,b,sigmab,disp,                              #4
-     &                 mcmc,nsave,tune1,                                #3
-     &                 acrate,cpo,randsave,thetasave,pssave,            #5
-     &                 seed,                                            #1
-     &                 iflagp,betac,workmp1,workmp2,workmhp1,workvp1,   #6       
-     &                 xtx,xty,                                         #2 
-     &                 iflagq,bc,workmq1,workmq2,workmhq1,workvq1,      #6       
-     &                 ztz,zty,ztzinv,theta,                            #4 
-     &                 mc,betasave,bsave,workvps)                       #4
+     &                (nrec,nfixed,p,nsmooth,q,starts,ends,nsmooths,    
+     &                 maxq,x,z,y,roffset,ngrid,znew,xreal,possfp,
+     &                 bet0,prec,sb,taub,iapm,japm,apm,nznh,pordv,      
+     &                 tau,                                             
+     &                 beta,b,sigmab,disp,                              
+     &                 mcmc,nsave,tune1,                                
+     &                 acrate,cpo,randsave,thetasave,pssave,            
+     &                 seed,                                            
+     &                 iflagp,betac,workmp1,workmp2,workmhp1,workvp1,         
+     &                 xtx,xty,                                         
+     &                 iflagq,bc,workmq1,workmq2,workmhq1,workvq1,            
+     &                 ztz,zty,ztzinv,theta,                            
+     &                 mc,betasave,bsave,workvps)                       
 c=======================================================================                      
-c     # of arguments = 63.
+c     # of arguments = 62.
 c
 c     Subroutine `psgamgam' to run a Markov chain in a semiparametric 
 c     gamma model, using a B-splines and penalties.
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara, 2007-2009.
 c
 c     The parametrization considered here is:
 c     log p(Y)= disp* ((-1/mu)*Y - log(mu)) + c(Y,disp),
@@ -51,16 +51,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c
@@ -91,7 +91,6 @@ c        ngrid       :  integer giving the number of grid points
 c                       where the curves are evaluated. 
 c        znew        :  real matrix giving the design for a grid
 c                       of values of the covariates, znew(ngrid,nsmooths). 
-c        zmean       :  real vector used to normalize, zmean(nsmooths). 
 c        xreal       :  real matrix giving the grid
 c                       of values of the covariates, xreal(ngrid,nsmooths). 
 c        possfp      :  integer vector giving the location of the 
@@ -241,7 +240,6 @@ c+++++Data
       integer starts(nsmooths),ends(nsmooths)
       integer possfp(nsmooths)
       real*8 roffset(nrec),x(nrec,p),z(nrec,q),znew(ngrid,q)
-      real*8 zmean(q)      
       real*8 xreal(ngrid,nsmooths)
       real*8 y(nrec)
       
@@ -736,7 +734,7 @@ c++++++++++++ likelihood evaluation
                  end do
               end do
 
-              call invdet2(ztz,maxq,jj,ztzinv,detlog,iflagq,workvq1)      
+              call invdet2(ztz,maxq,jj,ztzinv,detlog,iflagq,workvq1)
 
               do i=1,jj
                  tmp1=0.d0
@@ -937,7 +935,7 @@ c+++++++++++++ print
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                             
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
 
       do i=1,1+nsmooth
@@ -1003,4 +1001,4 @@ c+++++++++++++ print
       return
       end
       
-     
\ No newline at end of file
+     
