@@ -1,31 +1,30 @@
 c=======================================================================                      
       subroutine ptglmmprob
-     &                (datastr,maxni,nrec,nsubject,nfixed,p,q,subject,  #8 
-     &                 x,xtx,yr,y,z,                                    #5
-     &                 a0b0,mu0,prec1,prec2,sb,tinv,                    #6
-     &                 mcmc,nsave,                                      #2
-     &                 acrate,cpo,randsave,thetasave,                   #4
-     &                 curr,b,beta,betar,mu,sigma,                      #6 
-     &                 iflagp,res,workmp1,workmhp1,workvp1,             #5
-     &                 xty,                                             #1
-     &                 iflagr,parti,whicho,whichn,bz,bzc,limw,linf,lsup,#9
-     &                 propvr,sigmainv,theta,thetac,                    #4
-     &                 workmhr,workmr,workmr1,workmr2,workvr,ybar,ztz,  #7
-     &                 zty,                                             #1
-     &                 sigmac,sigmainvc,workmhr2,                       #3 
-     &                 massi,pattern,betasave,bsave)                    #4
+     &                (datastr,maxni,nrec,nsubject,nfixed,p,q,subject,
+     &                 x,xtx,yr,y,z,
+     &                 a0b0,mu0,prec1,prec2,sb,tinv,
+     &                 mcmc,nsave,
+     &                 acrate,cpo,randsave,thetasave,
+     &                 curr,b,beta,betar,mu,sigma,ortho,
+     &                 iflagp,res,workmp1,workmhp1,workvp1,
+     &                 xty,
+     &                 iflagr,parti,whicho,whichn,bz,bzc,limw,linf,lsup,
+     &                 propvr,sigmainv,theta,thetac,
+     &                 workmhr,workmr,workmr1,workmr2,workvr,ybar,
+     &                 sigmac,sigmainvc,workmhr2,
+     &                 massi,pattern,betasave,bsave)
 c=======================================================================                      
-c     # of arguments = 65.
+c     # of arguments = 64.
 c
 c     Subroutine `ptglmmprob' to run a Markov chain in a semiparametric 
 c     probit mixed effect model, using a Mixture of Multivariate Polya 
 c     trees prior for the distribution of the random effects.
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara and Timothy Hanson, 2007-2009.
 c
 c     Version 1.0:
 c
-c     Last modification: 30-04-2007.
+c     Last modification: 01-07-2008.
 c
 c     This program is free software; you can redistribute it and/or modify
 c     it under the terms of the GNU General Public License as published by
@@ -41,18 +40,29 @@ c     You should have received a copy of the GNU General Public License
 c     along with this program; if not, write to the Free Software
 c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
-c     The author's contact information:
+c     The authors' contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
+c
+c      Tim Hanson
+c      Division of Biostatistics
+c      University of Minnesota
+c      School of Public Health
+c      A460 Mayo Building, 
+c      MMC 303
+c      420 Delaware St SE
+c      Minneapolis, MN 55455
+c      Voice: 612-626-7075  URL  : http://www.biostat.umn.edu/~hanson/
+c      Fax  : 612-626-0660  Email: hanson@biostat.umn.edu
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -69,8 +79,6 @@ c        p           :  integer giving the number of fixed coefficients.
 c        q           :  integer giving the number of random effects.
 c        subject     :  integer vector giving the subject for each.
 c                       observation, subject(nsubject).
-c        typep       :  type of partition to be considered.
-c                       1=chol,2=square root 1, 3=square root 2.
 c        x           :  real matrix giving the design matrix for the 
 c                       fixed effects, x(nrec,p). 
 c        xtx         :  real matrix givind the product X^tX, xtx(p,p).
@@ -110,7 +118,7 @@ c                       inverted-Wishart prior distribution for the
 c                       covariance matrix of the random effects, 
 c                       sigma ~ Inv-Wishart(nu0,tinv^{-1}), such that 
 c                       E(sigma)=(1/(nu0-q-1)) * tinv 
-c                       (This is for the base line distribution)
+c                       (This is for the base line distribution).
 c
 c-----------------------------------------------------------------------
 c
@@ -124,6 +132,8 @@ c        nsave       :  integer giving the number of scans to be saved.
 c        nbase       :  integer giving the the number of scans where 
 c                       the baseline distribution and the precision
 c                       parameter are sampled.
+c        samplef     :  integer indicating whether the functionals
+c                       must be sampled (1) or not (0).          
 c        
 c-----------------------------------------------------------------------
 c
@@ -139,7 +149,7 @@ c        thetasave   :  real matrix containing the mcmc samples for
 c                       the averaged random effects, fixed effects, 
 c                       error variance, and mean and covariance of
 c                       the baseline distribution, 
-c                       thetsave(nsave,q+nfixed+q+2*nuniq(Sigma)+1).
+c                       thetsave(nsave,q+nfixed+q+2*nuniq(Sigma)+1+Q*Q).
 c
 c-----------------------------------------------------------------------
 c
@@ -160,6 +170,8 @@ c        sigma       :  real matrix giving the current value of the
 c                       covariance matrix for normal base line 
 c                       distribution for the random effects,
 c                       sigma(q,q).
+c        ortho       :  real matrix giving the current value of the
+c                       orthogonal matrix, ortho(q,q).
 c
 c-----------------------------------------------------------------------
 c
@@ -277,38 +289,35 @@ c                       Xt(Y-Zb), xty(p).
 c        ybar        :  real vector used to save the mean of random  
 c                       effects and the probabilities in each 
 c                       partition area, ybar(2**q).
-c        zty         :  real vector used to save the product 
-c                       Zt(Y-Xbeta), zty(q).
-c        ztz         :  real matrix used to save the product 
-c                       ZtSigma^1Z, ztz(q,q).
 c
 c=======================================================================                  
       implicit none 
 
 c+++++Data
       integer maxni,nrec,nsubject,nfixed,p,q,subject(nrec)
-      integer datastr(nsubject,maxni+1),yr(nrec),typep
-      real*8 y(nrec),x(nrec,p),z(nrec,q),xtx(p,p)	
+      integer datastr(nsubject,maxni+1),yr(nrec)
+      real*8 y(nrec),x(nrec,p),z(nrec,q),xtx(p,p)
       
 c+++++Prior 
-      integer fixed,m,murand,sigmarand
-      real*8 aa0,ab0,a0b0(6),mu0(q),nu0,prec1(p,p),prec2(q,q)
+      integer fixed,m,murand,sigmarand,typepr 
+      real*8 aa0,ab0,a0b0(7),mu0(q),nu0,prec1(p,p),prec2(q,q)
       real*8 sb(p)
       real*8 tinv(q,q)      
 
 c+++++MCMC parameters
-      integer mcmc(11),nburn,nskip,nsave,ndisplay,nbase
-      real*8 tune1,tune2,tune3
+      integer mcmc(12),nburn,nskip,nsave,ndisplay,nbase,samplef
+      real*8 tune1,tune2,tune3,tune4
 
 c+++++Output
-      real*8 acrate(4),cpo(nrec,2)
+      real*8 acrate(5),cpo(nrec,2)
       real*8 randsave(nsave,q*(nsubject+1))
-      real*8 thetasave(nsave,q+nfixed+q+(q*(q+1))+1)
+      real*8 thetasave(nsave,q+nfixed+q+(q*(q+1))+1+q*q)
 
 c+++++Current values of the parameters
       real*8 curr(6),cpar,beta(p),b(nsubject,q)
       real*8 betar(q)
       real*8 mu(q),sigma(q,q)
+      real*8 ortho(q,q)
 
 c+++++Working space - External
       integer iflagp(p) 
@@ -331,7 +340,6 @@ c+++++Working space - External
       real*8 workmr1(q,q),workmr2(q,q)
       real*8 workvr(q)
       real*8 ybar(2**q)
-      real*8 ztz(q,q),zty(q)
       
       real*8 sigmac(q,q),sigmainvc(q,q)
       real*8 workmhr2(q*(q+1)/2)
@@ -339,7 +347,7 @@ c+++++Working space - External
       integer massi(2**q)
       integer pattern(q)
 
-c++++ models performance
+c++++ model's performance
       real*8 mc(5)
       real*8 betasave(p),bsave(nsubject,q)
 
@@ -360,10 +368,11 @@ c+++++Working space - Internal
       real*8 logcgkn,logcgko
       real*8 loglikn,logliko
       real*8 logpriorn,logprioro
-      real*8 ratio,rtnorm,rtlnorm,runif,tmp1,tmp2
+      real*8 ratio,rnorm,rtnorm,rtlnorm,runif
       logical ainf,asup
+      real*8 tmp1,tmp2 
 
-c++++ models performance
+c++++ model's performance
       real*8 dbarc,dbar,dhat,pd,lpml
 
 c+++++CPU time
@@ -383,6 +392,11 @@ c+++++Adaptive MH for c
       integer adaptivec,cskip
       real*8 aratec
 
+
+c+++++Adaptive MH for partition
+      integer adaptivep,pskip
+      real*8 aratep
+
 c++++ parameters
       nburn=mcmc(1)
       nskip=mcmc(2)
@@ -391,10 +405,11 @@ c++++ parameters
       m=mcmc(5)
       seed1=mcmc(6)
       seed2=mcmc(7)
-      typep=mcmc(8)  
+      typepr=mcmc(8)  
       murand=mcmc(9)
       sigmarand=mcmc(10)
       fixed=mcmc(11)
+      samplef=mcmc(12)
       
       cpar=curr(1)
       
@@ -404,6 +419,7 @@ c++++ parameters
       tune1=a0b0(4)
       tune2=a0b0(5)
       tune3=a0b0(6)
+      tune4=a0b0(6)
       
       narea=2**q
       
@@ -414,98 +430,46 @@ c++++ transforming random effects and calculate log-likelihood
 c++++ for the baseline covariance matrix
 
       logliko=0.d0
+      call rhaar2(workmr,ortho,q,workmr1)
 
       do i=1,q
          mumh(i)=0.d0
          do j=1,q
-            sigmamh(i,j)=0.d0         
+            sigmamh(i,j)=0.d0
             workmr(i,j)=sigma(i,j)
          end do
       end do
+      call inversedet(workmr,q,iflagr,detlogl)
 
-      call invdet(workmr,q,sigmainv,detlogl,iflagr,workvr)
+      do i=1,q
+         do j=1,q
+            workmr(i,j)=0.d0
+            sigmainv(i,j)=0.d0
+         end do
+      end do
+      call cholesky(q,sigma,workmhr)
+      do i=1,q
+         do j=1,i
+            workmr(i,j)=workmhr(ihmssf(i,j,q))
+         end do
+      end do
 
-      if(typep.eq.1)then
-         do i=1,q
-            do j=1,q
-               workmr(i,j)=0.d0
-               sigmainv(i,j)=0.d0
-            end do
+      do i=1,q
+         do j=1,q
+            tmp1=0.d0
+            do k=1,q
+               tmp1=tmp1+workmr(i,k)*workmr1(k,j)
+            end do 
+            sigmainv(i,j)=tmp1  
          end do
-         call cholesky(q,sigma,workmhr)
-         do i=1,q
-            do j=1,i
-               sigmainv(i,j)=workmhr(ihmssf(i,j,q))
-            end do
-         end do
-         call inverse(sigmainv,q,iflagr)      
-         
-       else if(typep.eq.2)then
-         do i=1,q
-            do j=1,q
-               workmr(i,j)=sigma(i,j)
-               propvr(i,j)=0.d0
-               sigmainv(i,j)=0.d0
-            end do
-         end do
-         call eigenv(q,q,workmr,workvr,zty,ztz)
+      end do
 
-         do i=1,q
-            propvr(i,i)=sqrt(workvr(i))
-         end do
-         
-         do i=1,q
-            do j=1,q
-               tmp1=0.d0
-               do k=1,q
-                  tmp1=tmp1+ztz(i,k)*propvr(k,j)
-               end do
-               sigmainv(i,j)=tmp1
-            end do
-         end do
-         call inverse(sigmainv,q,iflagr)      
-      
-       else
-         do i=1,q
-            do j=1,q
-               workmr(i,j)=sigma(i,j)
-               propvr(i,j)=0.d0
-               sigmainv(i,j)=0.d0
-            end do
-         end do
-         call eigenv(q,q,workmr,workvr,zty,ztz)
-
-         do i=1,q
-            propvr(i,i)=sqrt(workvr(i))
-         end do
-
-         do i=1,q
-            do j=1,q
-               tmp1=0.d0
-               do k=1,q
-                  tmp1=tmp1+ztz(i,k)*propvr(k,j)
-               end do
-               workmr(i,j)=tmp1
-            end do
-         end do
-
-         do i=1,q
-            do j=1,q
-               tmp1=0.d0
-               do k=1,q
-                  tmp1=tmp1+workmr(i,k)*ztz(j,k)
-               end do
-               sigmainv(i,j)=tmp1
-            end do
-         end do
-         call inverse(sigmainv,q,iflagr)      
-      end if 
+      call inverse(sigmainv,q,iflagr)      
 
       call loglikpt_mucan(m,q,nsubject,parti,
      &                    whicho,whichn,b,bz,cpar,detlogl,
      &                    linf,lsup,mu,sigmainv,
-     &                    theta,workmhr,workmr,workvr,
-     &                    fixed,logliko)
+     &                    theta,fixed,logliko)
 
 c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 c++++ start the MCMC algorithm
@@ -526,6 +490,7 @@ c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
          tune2=10.0
          nburn=nburn+nadaptive
       end if  
+
       adaptivec=0
       aratec=0.d0
       cskip=0
@@ -534,6 +499,15 @@ c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
          tune3=1.0
          nburn=nburn+nadaptive
       end if  
+
+      adaptivep=0
+      aratep=0.d0
+      pskip=0
+      if(typepr.eq.1.and.tune4.lt.0.d0)then
+         adaptivep=1
+         tune4=1.d0
+         nburn=nburn+nadaptive
+      end if  
       
       nscan=nburn+(nskip+1)*(nsave)
 
@@ -664,11 +638,8 @@ c++++++++++ generating a candidate
             do j=1,q
                tmp1=0.d0
                do k=1,q
-                  propvr(j,k)=0.d0 
-                  ztz(j,k)=workmr(j,k)
-                  tmp1=tmp1+workmr(j,k)*mu(k)
+                  propvr(j,k)=workmr(j,k)
                end do
-               zty(j)=tmp1
                workvr(j)=0.d0
                iflagr(j)=0
             end do
@@ -683,41 +654,13 @@ c++++++++++ generating a candidate
                      tmp1=tmp1+z(datastr(i,l+1),j)*
      &                         z(datastr(i,l+1),k)
                   end do
-                  ztz(j,k)=ztz(j,k)+tmp1
+                  propvr(j,k)=propvr(j,k)+tmp1
                end do
             end do
 
-            do j=1,q
-               tmp1=0.d0
-               do k=1,ni
-                  tmp1=tmp1+z(datastr(i,k+1),j)*
-     &                      res(datastr(i,k+1))
-               end do
-               zty(j)=zty(j)+tmp1
-            end do                  
+            call inverse(propvr,q,iflagr)      
 
-            call inverse(ztz,q,iflagr)      
-
-c           do j=1,q
-c               limw(j)=0.d0
-c               tmp1=0.d0
-c               do k=1,q
-c                  tmp1=tmp1+ztz(j,k)*zty(k) 
-c               end do
-c               limw(j)=tmp1
-c            end do
-c            call rmvnorm(q,limw,ztz,workmhr,workvr,thetac)
-
-            call rmvnorm(q,theta,ztz,workmhr,workvr,thetac)
-
-
-c++++++++++ evaluating the candidate generating kernel
-
-c            call dmvn2(q,thetac,limw,ztz,logcgko,
-c     &                 workvr,workmr1,workmr2,iflagr)
-c
-c            call dmvn2(q,theta,limw,ztz,logcgkn,
-c     &                 workvr,workmr1,workmr2,iflagr)
+            call rmvnorm(q,theta,propvr,workmhr,workvr,thetac)
 
 
 c++++++++++ evaluating the likelihood
@@ -806,27 +749,15 @@ c++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 c+++++++ check if the user has requested an interrupt
          call rchkusr()
 
-c         do i=1,q
-c            betar(i)=0.d0
-c         end do
-c
-c         do i=1,nsubject
-c            do j=1,q
-c               betar(j)=betar(j)+b(i,j)
-c            end do
-c         end do
-c
-c         do i=1,q
-c            betar(i)=betar(i)/dble(nsubject)
-c         end do
-
-
 c+++++++ update the log-likelihood for random effects
-            
-         call loglikpt_updatet(m,q,nsubject,parti,
+
+         if(murand.eq.1.or.sigmarand.eq.1.or.aa0.gt.0.d0.or.
+     &      typepr.eq.1)then            
+            call loglikpt_updatet(m,q,nsubject,parti,
      &                         whicho,whichn,bz,cpar,detlogl,
      &                         linf,lsup,
      &                         fixed,logliko)
+         end if
 
          if(murand.eq.1)then
 
@@ -848,7 +779,7 @@ c++++++++++ generating a candidate
                         propvr(i,j)=(0.01d0)*sigma(i,j)/dble(nsubject)
                      end do
                   end do
-                  call rmvnorm(q,mu,propvr,workmhr,workvr,theta)            
+                  call rmvnorm(q,mu,propvr,workmhr,workvr,theta)
                 else
                   ratio=dble(runif())
                   if(ratio.le.0.25)then
@@ -857,21 +788,21 @@ c++++++++++ generating a candidate
                            propvr(i,j)=(5.4264d0/dble(q))*sigmamh(i,j)
                         end do
                      end do
-                     call rmvnorm(q,mu,propvr,workmhr,workvr,theta)            
+                     call rmvnorm(q,mu,propvr,workmhr,workvr,theta)
                    else if(ratio.le.0.5)then
                      do i=1,q
                         do j=1,q
                           propvr(i,j)=sigma(i,j)/dble(nsubject)
                         end do
                      end do
-                     call rmvnorm(q,mu,propvr,workmhr,workvr,theta)                               
+                     call rmvnorm(q,mu,propvr,workmhr,workvr,theta)
                    else
                      do i=1,q
                         do j=1,q
                           propvr(i,j)=0.01d0*sigma(i,j)/dble(nsubject)
                         end do
                      end do
-                     call rmvnorm(q,mu,propvr,workmhr,workvr,theta)            
+                     call rmvnorm(q,mu,propvr,workmhr,workvr,theta)
                   end if  
                end if  
             end if
@@ -902,8 +833,7 @@ c++++++++++ evaluating likelihood for muc
             call loglikpt_mucan(m,q,nsubject,parti,
      &                          whicho,whichn,b,bzc,cpar,detlogl,
      &                          linf,lsup,theta,sigmainv,
-     &                          thetac,workmhr,workmr,workvr,
-     &                          fixed,loglikn)
+     &                          thetac,fixed,loglikn)
 
 
 c++++++++++ acceptance step
@@ -1017,27 +947,27 @@ c++++++++++ generating the candidate value
                end do
             end do
 
-            call riwishart(q,nu,sigmac,sigmainvc,workmr,workvr,
+            call riwishart(q,nu,sigmac,workmr2,workmr,workvr,
      &                     workmhr,workmhr2,iflagr)
 
 c++++++++++ evaluating the candidate generating kernel
 
             do i=1,q
                do j=1,q
-                  ztz(i,j)=dble(nu-q-1)*sigma(i,j)
+                  propvr(i,j)=dble(nu-q-1)*sigma(i,j)
                end do
             end do
 
-            call diwishart(q,nu,sigmac,ztz,workmr1,workmr2,workvr,
+            call diwishart(q,nu,sigmac,propvr,workmr1,workmr2,workvr,
      &                     iflagr,logcgko)        
 
             do i=1,q
                do j=1,q
-                  ztz(i,j)=dble(nu-q-1)*sigmac(i,j)
+                  propvr(i,j)=dble(nu-q-1)*sigmac(i,j)
                end do
             end do
 
-            call diwishart(q,nu,sigma,ztz,workmr1,workmr2,workvr,
+            call diwishart(q,nu,sigma,propvr,workmr1,workmr2,workvr,
      &                     iflagr,logcgkn)        
 
 c++++++++++ ENDS: Simple MH
@@ -1052,13 +982,14 @@ c++++++++++ evaluating the prior
 
 c++++++++++ evaluating likelihood for sigmac
 
-            call loglikpt_covarcan(m,q,nsubject,iflagr,parti,
-     &                             whicho,whichn,b,bzc,cpar,detloglc,
-     &                             linf,lsup,mu,sigmac,sigmainvc,
-     &                             theta,workmhr,workmr,workvr,
-     &                             loglikn,typep,workmr1,workmr2,
-     &                             fixed)  
-     
+            call rhaar2(workmr,ortho,q,workmr1)
+
+            call loglikpt_covarcan2(m,q,nsubject,iflagr,parti,
+     &                              whicho,whichn,b,bzc,cpar,detloglc,
+     &                              linf,lsup,mu,sigmac,sigmainvc,
+     &                              workmr1,workvr,workmhr,workmr,
+     &                              loglikn,fixed)
+
 c++++++++++ acceptance step
          
             ratio=loglikn-logliko+logcgkn-logcgko+
@@ -1106,10 +1037,10 @@ c++++++++++ Addaptive MH
                    else 
                      if(aratec.gt.0.44)then
                         tune3=exp(log(tune3)+
-     &                        min(0.01,1.d0/sqrt(dble(iscan))))                     
+     &                        min(0.01,1.d0/sqrt(dble(iscan))))
                        else
                         tune3=exp(log(tune3)-
-     &                        min(0.01,1.d0/sqrt(dble(iscan))))                     
+     &                        min(0.01,1.d0/sqrt(dble(iscan))))
                      end if 
                   end if    
                   cskip=0
@@ -1138,8 +1069,7 @@ c++++++++++ the parameters
             call loglikpt_cparcan(m,q,nsubject,iflagr,parti,
      &                            whicho,whichn,bz,cparc,detlogl,
      &                            linf,lsup,
-     &                            theta,workmhr,workmr,workvr,
-     &                            fixed,loglikn)
+     &                            theta,fixed,loglikn)
 
 c++++++++++ acceptance step
             ratio=loglikn+logpriorn-logliko-logprioro+
@@ -1158,6 +1088,79 @@ c++++++++++ acceptance step
          baseskip=0
          end if
 
+c++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+c+++++++ Updating the partition                       +++
+c++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+
+         if(typepr.eq.1)then
+
+c++++++++++ Addaptive MH
+
+            if(adaptivep.eq.1)then  
+               pskip = pskip + 1
+               if(pskip.eq.100)then
+                  aratep=aratep/dble(100)
+                  if(iscan.le.nadaptive)then  
+                     if(aratep.lt.0.234)then
+                        tune4=exp(log(tune4)+(0.234-aratep))
+                      else
+                        tune4=exp(log(tune4)-(aratep-0.234))
+                     end if  
+                   else 
+                     if(aratep.gt.0.234)then
+                        tune4=exp(log(tune4)+
+     &                        min(0.01,1.d0/sqrt(dble(iscan))))
+                       else
+                        tune4=exp(log(tune4)-
+     &                        min(0.01,1.d0/sqrt(dble(iscan))))
+                     end if 
+                  end if    
+                  pskip=0
+                  aratep=0.d0
+               end if
+            end if
+
+c            call rhaar(q,workmr1,propvr)
+
+            do i=1,q
+               do j=1,q   
+                   workmr2(i,j)=rnorm(ortho(i,j),tune4*0.05d0)
+               end do
+            end do
+            call rhaar2(workmr,workmr2,q,propvr)
+
+            call loglikpt_covarcan2(m,q,nsubject,iflagr,parti,
+     &                              whicho,whichn,b,bzc,cpar,detloglc,
+     &                              linf,lsup,mu,sigma,sigmainvc,
+     &                              propvr,workvr,workmhr,workmr,
+     &                              loglikn,fixed)
+
+c++++++++++ acceptance step
+         
+            ratio=loglikn-logliko
+
+            if(log(dble(runif())).lt.ratio)then
+               acrate(5)=acrate(5)+1.d0
+               do i=1,q
+                  do j=1,q
+                     ortho(i,j)=workmr2(i,j)
+                     sigmainv(i,j)=sigmainvc(i,j)
+                  end do
+               end do
+
+               do i=1,nsubject
+                  do j=1,q
+                     bz(i,j)=bzc(i,j)
+                  end do   
+               end do 
+               detlogl=detloglc
+               logliko=loglikn
+
+               if(adaptivep.eq.1)aratep=aratep+1.d0
+
+            end if
+         end if 
+
 c++++++++++++++++++++++++++++++++++         
 c+++++++ save samples
 c++++++++++++++++++++++++++++++++++         
@@ -1184,77 +1187,32 @@ c+++++++++++++ predictive information
 
                call sampredptun(narea,q,nsubject,parti,m,ybar,
      &               massi,pattern,iflagr,whichn,whicho,bz,
-     &               cpar,limw,linf,lsup,workmr,workmhr,
-     &               workvr,thetac,fixed)
+     &               cpar,limw,linf,lsup,thetac,fixed)
 
-               if(typep.eq.1)then
-                  do i=1,q
-                     do j=1,q
-                        workmr(i,j)=0.d0
-                     end do
+               do i=1,q
+                  do j=1,q
+                     propvr(i,j)=0.d0
+                     workmr(i,j)=0.d0
                   end do
-                  call cholesky(q,sigma,workmhr)
-                  do i=1,q
-                     do j=1,i
-                        workmr(i,j)=workmhr(ihmssf(i,j,q))
-                     end do
+               end do
+               call cholesky(q,sigma,workmhr)
+               do i=1,q
+                  do j=1,i
+                     propvr(i,j)=workmhr(ihmssf(i,j,q))
                   end do
+               end do
 
-                else if(typep.eq.2)then
-                  do i=1,q
-                     do j=1,q
-                        workmr(i,j)=0.d0
-                        propvr(i,j)=0.d0
-                     end do
-                  end do
-                  call eigenv(q,q,sigma,workvr,zty,ztz)
+               call rhaar2(workmr,ortho,q,workmr1)
 
-                  do i=1,q
-                     propvr(i,i)=sqrt(workvr(i))
+               do i=1,q
+                  do j=1,q
+                     tmp1=0.d0
+                     do k=1,q
+                        tmp1=tmp1+propvr(i,k)*workmr1(k,j) 
+                     end do 
+                     workmr(i,j)=tmp1
                   end do
-         
-                  do i=1,q
-                     do j=1,q
-                        tmp1=0.d0
-                        do k=1,q
-                           tmp1=tmp1+ztz(i,k)*propvr(k,j)
-                        end do
-                        workmr(i,j)=tmp1
-                     end do
-                  end do
-                else
-                  do i=1,q
-                     do j=1,q
-                        workmr(i,j)=0.d0
-                        propvr(i,j)=0.d0
-                        workmr1(i,j)=0.d0
-                     end do
-                  end do
-                  call eigenv(q,q,sigma,workvr,zty,ztz)
-                  do i=1,q
-                     propvr(i,i)=sqrt(workvr(i))
-                  end do
-
-                  do i=1,q
-                     do j=1,q
-                        tmp1=0.d0
-                        do k=1,q
-                           tmp1=tmp1+ztz(i,k)*propvr(k,j)
-                        end do
-                        workmr1(i,j)=tmp1
-                     end do
-                  end do
-
-                  do i=1,q
-                     do j=1,q
-                        tmp1=0.d0
-                        do k=1,q
-                           tmp1=tmp1+workmr1(i,k)*ztz(j,k)
-                        end do
-                        workmr(i,j)=tmp1
-                     end do
-                  end do
-               end if 
+               end do
 
                k=nsubject*q
                do i=1,q
@@ -1269,8 +1227,10 @@ c+++++++++++++ predictive information
 
 c+++++++++++++ functional parameter
 
+               if(samplef.eq.1)then
+
                call samplefuncpt(fixed,m,q,nsubject,cpar,bz,theta,
-     &                           iflagr,pattern,thetac,ztz)  
+     &                           iflagr,pattern,thetac,workmr1)  
 
                do i=1,q
                   tmp1=0.d0
@@ -1284,7 +1244,7 @@ c+++++++++++++ functional parameter
                   do j=1,q
                      tmp1=0.d0  
                      do k=1,q
-                        tmp1=tmp1+workmr(i,k)*ztz(k,j)                  
+                        tmp1=tmp1+workmr(i,k)*workmr1(k,j)
                      end do
                      propvr(i,j)=tmp1
                   end do
@@ -1294,7 +1254,7 @@ c+++++++++++++ functional parameter
                   do j=1,q
                      tmp1=0.d0  
                      do k=1,q
-                        tmp1=tmp1+propvr(i,k)*workmr(j,k)                  
+                        tmp1=tmp1+propvr(i,k)*workmr(j,k)
                      end do
                      workmr1(i,j)=tmp1
                   end do
@@ -1305,11 +1265,12 @@ c+++++++++++++ regression coefficients
                do i=1,q
                   thetasave(isave,i)=betar(i)
                end do
+               end if
 
                if(nfixed.gt.0)then
                   do i=1,p
                      thetasave(isave,q+i)=beta(i)
-                     betasave(i)=betasave(i)+beta(i)                     
+                     betasave(i)=betasave(i)+beta(i)
                   end do
                end if   
 
@@ -1333,12 +1294,23 @@ c+++++++++++++ precision parameter
                k=(q*(q+1)/2)  
                thetasave(isave,q+nfixed+q+k+1)=cpar
 
+c+++++++++++++ type of partition
+               call rhaar2(workmr,ortho,q,workmr2)
+
+               k=(q*(q+1)/2)+1
+               do i=1,q
+                  do j=1,q
+                     k=k+1
+                     thetasave(isave,q+nfixed+q+k)=workmr2(i,j) 
+                  end do
+               end do   
+
 c+++++++++++++ random effects variance
                l=0
                do i=1,q
                   do j=i,q
                      l=l+1
-                     thetasave(isave,q+nfixed+q+k+1+l)=workmr1(i,j)
+                     thetasave(isave,q+nfixed+q+k+l)=workmr1(i,j)
                   end do
                end do   
 
@@ -1349,8 +1321,8 @@ c+++++++++++++ cpo
                   do j=1,p
                      tmp1=tmp1+x(i,j)*beta(j)
                   end do
-		  do j=1,q
-		     tmp1=tmp1+z(i,j)*b(subject(i),j)
+                  do j=1,q
+                     tmp1=tmp1+z(i,j)*b(subject(i),j)
                   end do
 
                   tmp1=cdfnorm(tmp1,0.d0,1.d0,1,0)
@@ -1386,6 +1358,7 @@ c+++++++++++++ print
       do i=2,4
          acrate(i)=acrate(i)*dble(nbase)/dble(nscan)
       end do
+      acrate(5)=acrate(5)/dble(nscan)
       
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
@@ -1409,8 +1382,8 @@ c+++++++++++++ print
          do j=1,p
             tmp1=tmp1+x(i,j)*betasave(j)
          end do
-	 do j=1,q
-	   tmp1=tmp1+z(i,j)*bsave(subject(i),j)
+         do j=1,q
+            tmp1=tmp1+z(i,j)*bsave(subject(i),j)
          end do
 
          tmp1=cdfnorm(tmp1,0.d0,1.d0,1,0)
@@ -1434,4 +1407,4 @@ c+++++++++++++ print
       
       return
       end
-         
\ No newline at end of file
+         
