@@ -1,19 +1,19 @@
     
 c=======================================================================                      
-      subroutine tdpdensity(nrec,jacob,x,                               #3
-     &                      a0b0,a0,b0,kmax,                            #4
-     &                      k,ncluster,ss,alpha,yclus,                  #5
-     &                      mcmc,nsave,                                 #2
-     &                      cpo,randsave,thetasave,ngrid,grid,fun,      #6 
-     &                      seed,                                       #1
-     &                      cstrt,ccluster,prob,probk,y)                #5 
+      subroutine tdpdensity(nrec,jacob,x,                               
+     &                      a0b0,a0,b0,kmax,                            
+     &                      k,ncluster,ss,alpha,yclus,                  
+     &                      mcmc,nsave,                                 
+     &                      cpo,randsave,thetasave,ngrid,grid,fun,       
+     &                      seed,                                       
+     &                      cstrt,ccluster,prob,probk,y)
 c=======================================================================                      
 c     # of arguments = 26.
 c
 c     Subroutine `tdpdensity' to run a Markov chain for a 
 c     Triangular-Dirichlet model.
 c
-c     Copyright: Alejandro Jara, 2007
+c     Copyright: Alejandro Jara, 2007-2009.
 c
 c     Version 1.0:
 c
@@ -35,16 +35,16 @@ c     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 c
 c     The author's contact information:
 c
-c     Alejandro Jara
-c     Biostatistical Centre
-c     Katholieke Universiteit Leuven
-c     U.Z. Sint-Rafal
-c     Kapucijnenvoer 35
-c     B-3000 Leuven
-c     Voice: +32 (0)16 336892 
-c     Fax  : +32 (0)16 337015 
-c     URL  : http://student.kuleuven.be/~s0166452/
-c     Email: Alejandro.JaraVallejos@med.kuleuven.be
+c      Alejandro Jara
+c      Department of Statistics
+c      Facultad de Ciencias Fsicas y Matemticas
+c      Universidad de Concepcin
+c      Avenida Esteban Iturra S/N
+c      Barrio Universitario
+c      Concepcin
+c      Chile
+c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
+c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
 c
 c---- Data -------------------------------------------------------------
 c 
@@ -297,8 +297,8 @@ c++++++++++ subject in cluster with only 1 observation
                if(since.lt.ncluster)then
                    call  relabelmeta(i,since,nrec,ncluster,cstrt,
      &                               ccluster,ss,yclus)
-	       end if
-	              
+               end if
+
                ccluster(ncluster)=ccluster(ncluster)-1 
                ncluster=ncluster-1
 
@@ -535,7 +535,7 @@ c+++++++++++++ print
 
       do i=1,nrec
          cpo(i,1)=dble(nsave)/cpo(i,1)
-         cpo(i,2)=cpo(i,2)/dble(nsave)                                             
+         cpo(i,2)=cpo(i,2)/dble(nsave)
       end do
 
       do i=1,ngrid
@@ -547,4 +547,4 @@ c+++++++++++++ print
       end do     
 
       return
-      end
\ No newline at end of file
+      end
